@@ -98,7 +98,7 @@ public class ReadCDF implements CDFConstants{
               System.out.println("Compression:  "+cdf.getCompression());
               if (cdf.getCompressionType() != 0)
                 System.out.println("cPct:         "+cdf.getCompressionPct());
-              if (new Integer(cdf.getVersion().substring(0,1)).intValue() > 3) {
+              if (Integer.valueOf(cdf.getVersion().substring(0,1)) > 3) {
                 long lsLastUpdated = cdf.getLeapSecondLastUpdated();
                 if (lsLastUpdated > 0)
 		  System.out.println("LeapSecondLastUpdated:     "+lsLastUpdated);
@@ -229,8 +229,10 @@ public class ReadCDF implements CDFConstants{
                             }
                           } else
                             CDFUtils.printData (data);
+//                          if (eDataType == CDF_REAL4 || eDataType == CDF_REAL8 ||
+//                              eDataType == CDF_FLOAT || eDataType == CDF_DOUBLE)	
+//                            System.out.println (" ");
                        }
-                       System.out.println (" ");
                     }
                 }
                 System.out.println (" ");
