@@ -42,6 +42,7 @@
 *****************************************************************************/
 
 #include "cdfdist.h"
+#include <limits.h>
 
 /*****************************************************************************
 * Miscellaneous.
@@ -50,6 +51,7 @@
 #define INPUT_MAJOR             0
 #define useDEFAULTcacheSIZE	0
 #define useDEFAULTrecordNUM     0
+#define dots3			"..."
 
 /*****************************************************************************
 * Macintosh-specific...
@@ -192,33 +194,39 @@ char *qualOpt[QOP_MAX_QUALs];
 
 #if defined(alphaosf) || defined(IRIX64bit) || defined(_LP64) || \
     defined(__amd64) || defined(__x86_64__) || defined(__ia64__) || \
-    defined(__PPC64__) || defined(__ppc64__)
+    defined(__PPC64__) || defined(__ppc64__) || defined(__arm64__)
 #  define Int32FORMAT	"%d"
 #  define Int64FORMAT   "%lld"
 #  define Int32uFORMAT	"%u"
 #  define Int32FORMATmod	""
 #  define Int64FORMATmod        "ll"
-#  define Int32hexFORMAT	"0x%08X"
+#  define Int32hexFORMAT0x	"0x%08X"
+#  define Int32hexFORMAT	"%08X"
 #  if defined(alphaosf)
-#    define Int64hexFORMAT      "0x%016X"
+#    define Int64hexFORMAT0x    "0x%016X"
+#    define Int64hexFORMAT      "%016X"
 #  else
-#    define Int64hexFORMAT      "0x%016llX"
+#    define Int64hexFORMAT0x    "0x%016llX"
+#    define Int64hexFORMAT      "%016llX"
 #  endif
 #else
-#  define Int32FORMAT	"%ld"
+#  define Int32FORMAT	"%d"
 #if defined(win32) || defined(__MINGW32__)
 #  define Int64FORMAT   "%I64d"
 #else
 #  define Int64FORMAT   "%lld"
 #endif
-#  define Int32uFORMAT	"%lu"
+#  define Int32uFORMAT	"%u"
 #  define Int32FORMATmod	"l"
 #  define Int64FORMATmod	"ll"
-#  define Int32hexFORMAT	"0x%08lX"
+#  define Int32hexFORMAT0x	"0x%08X"
+#  define Int32hexFORMAT	"%08X"
 #if defined(win32) || defined(__MINGW32__)
-#  define Int64hexFORMAT        "0x%016I64X"
+#  define Int64hexFORMAT0x      "0x%016I64X"
+#  define Int64hexFORMAT        "%016I64X"
 #else
-#  define Int64hexFORMAT        "0x%016llX"
+#  define Int64hexFORMAT0x      "0x%016llX"
+#  define Int64hexFORMAT        "%016llX"
 #endif
 #endif
 
@@ -366,6 +374,7 @@ struct HyperStruct {
 
 #define BLANKs78 "                                                                                                 "
 #define BLANKs40 "                                             "
+#define BLANKs72 "                                                                                           "
 
 /*****************************************************************************
 * Symbol(s) for displaying illegal/special values.
@@ -408,7 +417,7 @@ struct HyperStruct {
 #if defined(mac)
 #  define MAIN int main ()
 #else
-#  define MAIN int main (argc, argv) int argc; char *argv[];
+#  define MAIN int main (int argc, char *argv[])
 #endif
 
 /******************************************************************************
@@ -647,7 +656,6 @@ extern int lastSecond;
 * Function prototypes.
 *****************************************************************************/
 
-int UTF8StrLength PROTOARGs((unsigned char *, int));
 void ASSIGNx PROTOARGs((void *, void *, long, long));
 Logical EQx PROTOARGs((void *, void *, long, long));
 Logical NEx PROTOARGs((void *, void *, long, long));
@@ -658,6 +666,7 @@ Logical GTx PROTOARGs((void *, void *, long, long));
 Logical IsDir PROTOARGs((char *));
 Logical IsWild PROTOARGs((char *));
 Logical IsCDF PROTOARGs((char *));
+Logical IsHexFormat PROTOARGs((char *));
 void EncodeRecordJustify PROTOARGs((char *string, long recN, int minWidth,
   size_t width
 ));
@@ -695,8 +704,9 @@ int EncodeRecordIndices PROTOARGs((char *, long, long, long, long *, long *,
   size_t
 ));
 int EncodeRecordIndicesVARY PROTOARGs((char *, long, long, long *, size_t));
-int EncodeString PROTOARGs((long, char *, char *, int, int));
+void EncodeString PROTOARGs((long, char *, char *, int, int));
 int EncodeValue PROTOARGs((long, void *, char *, int, size_t));
+int EncodeValueSKT PROTOARGs((long, void *, char *, int, size_t));
 int EncodeValueFormat PROTOARGs((
   long dataType, void *binary, char *text, char *format, int minWidth,
   int maxWidth, int style, size_t width
@@ -707,7 +717,9 @@ int EncodeValuesFormat PROTOARGs((
 ));
 void EncodeNegativeZero PROTOARGs((char *string, char *format, size_t width));
 void WriteStringValue PROTOARGs((FILE *, long, void *, int, int));
-void WriteEntryValue PROTOARGs((FILE *, long, long, void *, int, int, int));
+void WriteEntryValue PROTOARGs((FILE *, long, long, void *, int, int, int, char *));
+void WriteEntryValueSKT PROTOARGs((FILE *, long, long, void *, int, int, int,
+                                   char *));
 char *EncodingToken PROTOARGs((long));
 char *MajorityToken PROTOARGs((long));
 char *FormatToken PROTOARGs((long));
@@ -720,6 +732,7 @@ char *SparsenessToken PROTOARGs((
   long sRecordsType, long sArraysType, long sArraysParms[CDF_MAX_PARMS]
 ));
 char *ChecksumToken PROTOARGs((long));
+int  IsFloatingValidValue PROTOARGs((long, void *));
 long WhichDataType PROTOARGs((char *));
 long WhichFormat PROTOARGs((char *));
 long WhichMajority PROTOARGs((char *));
@@ -778,7 +791,7 @@ Logical S6qualifierLong PROTOARGs((
 ));
 void BlankPadRight PROTOARGs((char *string, int count));
 void NulPadRight PROTOARGs((char *string, int count));
-CDFstatus GetFormatEntry PROTOARGs((Logical, long, char **));
+CDFstatus GetFORMATEntry PROTOARGs((CDFid, Logical, long, char **));
 Logical ParseOptionList PROTOARGs((
   int nTokens, char *tokens[], char *list, Logical present[]
 ));
@@ -795,6 +808,10 @@ int CDFdirList PROTOARGs((char *path, char ***dirS, char ***nameS));
 void RemoveExtensions PROTOARGs((int, char **));
 char *TempCharStr PROTOARGs((int character));
 char *EpochDateTimeString PROTOARGs((long datatype, int style, double *epoch));
+void GetDefaultPadValue PROTOARGs((CDFid id, long datatype, void *value));
+void ReplacePadValues PROTOARGs((void *buffer, void *pad, void *filled,
+                                 long dataType, int values
+));
 void DisplayStatistics PROTOARGs((
   char *label, vSTATS *vStatsDotCDF, vSTATS *vStatsStage,
   vSTATS *vStatsCompress
@@ -876,6 +893,27 @@ int BinarySearch PROTOARGs((
 void MergeSort PROTOARGs((
   long dataType, void *values, void *tmp, int left, int right
 ));
+int numSpaces PROTOARGs((long n));
+int numCharsShown PROTOARGs((size_t total, int used, char *string));
+int UTF8CharWidth PROTOARGs((const char *));
+int UTF8CharAtPosition PROTOARGs((const char *, int));
+int UTF8CharAtWidth PROTOARGs((const char *string, int charNum));
+int UTF8FirstCharsBytes PROTOARGs((const char *string, int numChars));
+int UTF8FirstCharsWidth PROTOARGs((const char *string, int numChars));
+int UTF8StrWidth PROTOARGs((const char *string));
+int UTF8FindFirstChar PROTOARGs((const char *string, int lastChar, int limit));
+int UTF8FindLastChar PROTOARGs((const char *string, int firstChar, 
+                                int totalChars, int limit));
+int UTF8FrontCharsWithinWidth PROTOARGs((const char *string, int width));
+int UTF8BackCharsWithinWidth PROTOARGs((const char *string, int width));
+int UTF8WCharWidth PROTOARGs((wchar_t));
+int UTF8WCharsWidth PROTOARGs((const wchar_t *, int));
+int UTF8HasWiderChar PROTOARGs((const char *));
+int GetWideCharWidth PROTOARGs((wchar_t));
+int GetWideCharsWidth PROTOARGs((const wchar_t *, size_t));
+
+int GetUTF8CharWidth PROTOARGs((wchar_t));
+
 #if defined(mac)
 void MacExecuteSO PROTOARGs((
   Logical (*exeFnc)(int argC, char *argV[]),
@@ -885,7 +923,7 @@ void MacExecuteFSI PROTOARGs((
   Logical (*exeFnc)(int argC, char *argV[]),
   Logical (*qopFnc)(int *argC, char **argV[])
 ));
-void MacExecuteTimer PROTOARGs((Logical (*exeFnc)(), int argC, char *argV[]));
+void MacExecuteTimer PROTOARGs((Logical (*exeFnc)(void), int argC, char *argV[]));
 void MacMessageDialog PROTOARGs((char *severityText, char *messageText));
 void InitMacUI PROTOARGs((void));
 void FreeMacQOPs PROTOARGs((int argC, char *argV[]));
