@@ -38,11 +38,17 @@
 #if !defined(WINDOZh_INCLUDEd__)
 #define WINDOZh_INCLUDEd__
 
+#define _XOPEN_SOURCE_EXTENDED
+#if defined(__CYGWIN__)
+#  define _XOPEN_SOURCE 700
+#endif
+
 /******************************************************************************
 * Include files.
 ******************************************************************************/
 
 #include "cdftools.h"
+#include <wchar.h>
 
 /******************************************************************************
 * Which type of screen management is being used?
@@ -170,7 +176,7 @@ typedef int chtype;
 #  if defined(ultrix) || defined(AIX) || defined(hpux)
 #    define problemACS
 #  endif
-#  if defined(alphaosf) || defined(IRIX64bit) || defined(SOLARIS64) || \
+#  if defined(alphaosf) || defined(IRIX64bit) || defined(_LP64) || \
       defined(posixSHELL) || defined(__QNX__) || \
       defined(__CYGWIN__) || defined(__MINGW32__)
 #    define problemACS
@@ -582,9 +588,17 @@ int paste_virtual_display PROTOARGs((WINDOWid, int, int));
 int put_chars PROTOARGs((WINDOWid, char *, int, int, int, int, int));
 int read_display PROTOARGs((WINDOWid, int, char *));
 #if defined(CURSESui)
-  int read_input PROTOARGs((WINDOWid, int *, int, Logical));
+  #if defined(WIN32)
+    int read_input PROTOARGs((WINDOWid, int *, int, Logical));
+  #else
+    int read_input PROTOARGs((WINDOWid, wint_t *, int, Logical));
+  #endif
 #else
-  int read_input PROTOARGs((int *, int, Logical));
+  #if defined(WIN32)
+    int read_input PROTOARGs((int *, int, Logical));
+  #else
+    int read_input PROTOARGs((wint_t *, int, Logical));
+  #endif
 #endif
 int repaint_screen PROTOARGs((void));
 int repaste_virtual_display PROTOARGs((WINDOWid, int, int));
