@@ -78,10 +78,10 @@ static CDFstatus AllocateCVVR PROTOARGs((
 * AllocateRecords.
 ******************************************************************************/
 
-STATICforIDL CDFstatus AllocateRecords (CDF, Var, alloc)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct alloc;
+STATICforIDL CDFstatus AllocateRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct alloc)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 vxrHead, toRec, vxrHeadNew; int count, newCount;
@@ -139,13 +139,13 @@ struct AllocStruct alloc;
 * InsertRecords.
 ******************************************************************************/
 
-static CDFstatus InsertRecords (CDF, Var, alloc, vxrStart, count, toRec)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct alloc;
-Int32 vxrStart;
-int *count;
-Int32 *toRec;
+static CDFstatus InsertRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct alloc,
+Int32 vxrStart,
+int *count,
+Int32 *toRec)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct VXR;
   Int32 vxrOffset = vxrStart, irType, vxrOffsetNew, lastNew;
@@ -302,12 +302,12 @@ Int32 *toRec;
 * AppendRecords.
 ******************************************************************************/
 
-static CDFstatus AppendRecords (CDF, Var, alloc, vxrStart, count)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
-Int32 vxrStart;
-int *count;
+static CDFstatus AppendRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc,
+Int32 vxrStart,
+int *count)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct VXR;
   Int32 vxrOffset = vxrStart, irType, vxrOffsetNew, lastNew;
@@ -369,13 +369,13 @@ int *count;
 * InsertEntry.
 ******************************************************************************/
 
-static CDFstatus InsertEntry (CDF, Var, alloc, vxrOffset, atEntryN, count)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
-Int32 vxrOffset;
-int atEntryN;
-int *count;
+static CDFstatus InsertEntry (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc,
+Int32 vxrOffset,
+int atEntryN,
+int *count)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 vxrOffsetNew, vrOffset, pushFirst, pushLast, pushOffset;
@@ -430,17 +430,16 @@ int *count;
 * InsertAtEntry.
 ******************************************************************************/
 
-static void InsertAtEntry (first, last, offset, VXR, atEntryN, push,
-			   pushFirst, pushLast, pushOffset)
-Int32 first;
-Int32 last;
-Int32 offset;
-struct VXRstruct *VXR;
-int atEntryN;
-Logical *push;
-Int32 *pushFirst;
-Int32 *pushLast;
-Int32 *pushOffset;
+static void InsertAtEntry (
+Int32 first,
+Int32 last,
+Int32 offset,
+struct VXRstruct *VXR,
+int atEntryN,
+Logical *push,
+Int32 *pushFirst,
+Int32 *pushLast,
+Int32 *pushOffset)
 {
   int startEntryN, entryN;
   if (VXR->NusedEntries < VXR->Nentries) {
@@ -471,12 +470,12 @@ Int32 *pushOffset;
 *   It is assumed that the offset is for a VXR at the end of a linked list.
 ******************************************************************************/
 
-static CDFstatus AppendEntry (CDF, Var, alloc, vxrOffset, count)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
-Int32 vxrOffset;
-int *count;
+static CDFstatus AppendEntry (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc,
+Int32 vxrOffset,
+int *count)
 {
   CDFstatus pStatus = CDF_OK; Logical resized;
   struct VXRstruct VXR, newVXR; Int32 offset, vxrOffsetNew;
@@ -562,11 +561,11 @@ int *count;
 * PadSparseRecords.
 ******************************************************************************/
 
-static CDFstatus PadSparseRecords (CDF, Var, offset, nRecords)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 offset;
-Int32 nRecords;
+static CDFstatus PadSparseRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+Int32 offset,
+Int32 nRecords)
 {
   CDFstatus pStatus = CDF_OK; int how; void *buffer;
   if (!sX(BuildPadBuffer(CDF,Var,nRecords,
@@ -584,10 +583,10 @@ Int32 nRecords;
 * CountVXRs.
 ******************************************************************************/
 
-static CDFstatus CountVXRs (CDF, vxrStart, count)
-struct CDFstruct *CDF;
-Int32 vxrStart;
-int *count;
+static CDFstatus CountVXRs (
+struct CDFstruct *CDF,
+Int32 vxrStart,
+int *count)
 {
   CDFstatus pStatus = CDF_OK; Int32 vxrOffset = vxrStart;
   *count = 0;
@@ -604,11 +603,11 @@ int *count;
 * InitNewVXR.
 ******************************************************************************/
 
-STATICforIDL void InitNewVXR (VXR, firstRec, lastRec, offset)
-struct VXRstruct *VXR;
-Int32 firstRec;
-Int32 lastRec;
-Int32 offset;
+STATICforIDL void InitNewVXR (
+struct VXRstruct *VXR,
+Int32 firstRec,
+Int32 lastRec,
+Int32 offset)
 {
   int entryN;
   VXR->RecordSize = VXR_BASE_SIZE;
@@ -631,8 +630,8 @@ Int32 offset;
 * InitNewVXRx.
 ******************************************************************************/
 
-static void InitNewVXRx (VXRx)
-struct VXRstruct *VXRx;
+static void InitNewVXRx (
+struct VXRstruct *VXRx)
 {
   int entryN;
   VXRx->RecordSize = VXRx_BASE_SIZE;
@@ -652,10 +651,10 @@ struct VXRstruct *VXRx;
 * FirstRecords.
 ******************************************************************************/
 
-static CDFstatus FirstRecords (CDF, Var, alloc)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
+static CDFstatus FirstRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc)
 {
   CDFstatus pStatus = CDF_OK;
   struct VXRstruct VXR; Int32 offset, vxrOffset;
@@ -676,14 +675,13 @@ struct AllocStruct *alloc;
 * ExtendLevel.
 ******************************************************************************/
 
-static CDFstatus ExtendLevel (CDF, vxrOffset, count, vxrOffsetHead, lastNew,
-			      countNew)
-struct CDFstruct *CDF;
-Int32 vxrOffset;
-int count;
-Int32 *vxrOffsetHead;
-Int32 *lastNew;
-int *countNew;
+static CDFstatus ExtendLevel (
+struct CDFstruct *CDF,
+Int32 vxrOffset,
+int count,
+Int32 *vxrOffsetHead,
+Int32 *lastNew,
+int *countNew)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct VXR;
   if (!sX(ReadVXR(CDF->fp,vxrOffset,
@@ -703,12 +701,12 @@ int *countNew;
 * CreateLevel.
 ******************************************************************************/
 
-static CDFstatus CreateLevel (CDF, vxrOffset, count, vxrOffsetHead, newCount)
-struct CDFstruct *CDF;
-Int32 vxrOffset;
-int count;
-Int32 *vxrOffsetHead;
-int *newCount;
+static CDFstatus CreateLevel (
+struct CDFstruct *CDF,
+Int32 vxrOffset,
+int count,
+Int32 *vxrOffsetHead,
+int *newCount)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 sizeOfVXRx = VXRx_BASE_SIZE;
@@ -800,11 +798,11 @@ int *newCount;
 * AllocateVR.
 ******************************************************************************/
 
-static CDFstatus AllocateVR (CDF, Var, alloc, offset)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
-Int32 *offset;
+static CDFstatus AllocateVR (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc,
+Int32 *offset)
 {
   CDFstatus pStatus = CDF_OK;
   switch (alloc->type) {
@@ -840,11 +838,11 @@ Int32 *offset;
 * AllocateVVR.
 ******************************************************************************/
 
-static CDFstatus AllocateVVR (CDF, Var, nRecords, vvrOffset)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 nRecords;
-Int32 *vvrOffset;
+static CDFstatus AllocateVVR (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+Int32 nRecords,
+Int32 *vvrOffset)
 {
   CDFstatus pStatus = CDF_OK; struct VVRstruct VVR;
   VVR.RecordSize = (Int32) (VVR_BASE_SIZE + (nRecords * Var->NphyRecBytes));
@@ -862,11 +860,11 @@ Int32 *vvrOffset;
 * AllocateCVVR.
 ******************************************************************************/
 
-static CDFstatus AllocateCVVR (CDF, cSize, xSize, cvvrOffset)
-struct CDFstruct *CDF;
-Int32 cSize;
-Int32 xSize;
-Int32 *cvvrOffset;
+static CDFstatus AllocateCVVR (
+struct CDFstruct *CDF,
+Int32 cSize,
+Int32 xSize,
+Int32 *cvvrOffset)
 {
   CDFstatus pStatus = CDF_OK; struct CVVRstruct CVVR;
   CVVR.RecordSize = (Int32) (CVVR_BASE_SIZE + cSize + xSize);
@@ -886,9 +884,9 @@ Int32 *cvvrOffset;
 * UpdateVXRtailInVDR.
 ******************************************************************************/
 
-STATICforIDL CDFstatus UpdateVXRtailInVDR (CDF, Var)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
+STATICforIDL CDFstatus UpdateVXRtailInVDR (
+struct CDFstruct *CDF,
+struct VarStruct *Var)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct VXR;
   Int32 vxrOffset, irType; int lastEntryN;
