@@ -33,9 +33,9 @@
 * CDFcon64.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFcon64 (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFcon64 (
+struct VAstruct *Va,
+struct CurStruct *Cur)
 {
 CDFstatus tStatus, pStatus = CDF_OK;
 
