@@ -22,8 +22,8 @@
 *
 ******************************************************************************/
 
-#include "zlib/zconf.h"
-#include "zlib/zlib.h"
+#include "zconf.h"
+#include "zlib.h"
 #include "cdflib.h"
 #include "cdflib64.h"
 
@@ -32,63 +32,67 @@
 /****************************************************************************
  * Local functions.
  ****************************************************************************/
-static int defgzip(vFILE *src, vFILE *dst, OFF_T iSize, OFF_T *osize,
-                   int level);
-static int infgzip(vFILE *src, OFF_T iSize, vFILE *dst);
 
-/* Compress from file source to file dest until EOF on source.
+static int defgzip(vFILE *src, vFILE *dst, OFF_T iSize, OFF_T *oSize,
+		   int level);
+static int infgzip(vFILE *src, OFF_T iSize, vFILE *dst, OFF_T oSize);
+
+/* Compress from file source to file dest for a given number of bytes in source.
    defgzip() returns CDF_OK on success, or ZLIB_COMPRESS_ERROR for any error,
    .e.g., if memory could not be allocated for processing, an invalid
    compression level is supplied, the version of zlib.h and the
    version of the library linked do not match, or there is
    an error reading or writing the files. */
 
-static int defgzip(vFILE *source, vFILE *dest, OFF_T iSize, OFF_T *osize,
-                   int level)
+static int defgzip(vFILE *source, vFILE *dest, OFF_T iSize, OFF_T *oSize,
+		   int level)
 {
     int ret, flush;
     unsigned have;
     z_stream strm;
-    uChar in[CHUNK];
-    uChar out[CHUNK];
-    OFF_T remaining;
-    unsigned mySize;
+    /* Extra space (256) added in case the aggragated size from the number of
+       blocking factor is larger than MIN_BLOCKING_BYTES_compressed. */
+    uChar in[CHUNK+256];
+    uChar out[CHUNK+256];
+    OFF_T remaining, iRead, oWrite, extra;
 
-    *osize = 0;
+    *oSize = 0;
     strm.zalloc = Z_NULL;
     strm.zfree = Z_NULL;
     strm.opaque = Z_NULL;
+    extra = CHUNK + 256;
     ret = deflateInit2(&strm, level, Z_DEFLATED, MAX_WBITS+16, 8, 0);
     if (ret != Z_OK) return ZLIB_COMPRESS_ERROR;
     remaining = iSize;
     do {
-        if (remaining > CHUNK) mySize = CHUNK;
-        else mySize = (unsigned) remaining;
-        strm.avail_in = (unsigned) V_read64(in, (size_t) 1, (size_t) mySize,
-                                            source);
-        flush = (remaining == (OFF_T) mySize) ? Z_FINISH : Z_NO_FLUSH;
+        if (remaining > extra) iRead = extra;
+        else iRead = remaining;
+        strm.avail_in = (unsigned) V_read64(in, (size_t) 1, iRead, source);
+        if (strm.avail_in != iRead) return VAR_READ_ERROR;
+        flush = (remaining == iRead) ? Z_FINISH : Z_NO_FLUSH;
         strm.next_in = in;
         do {
-            strm.avail_out = CHUNK;
+            strm.avail_out = extra;
             strm.next_out = out;
             ret = deflate(&strm, flush);
             if (ret == Z_STREAM_ERROR)
               return ZLIB_COMPRESS_ERROR;
-            have = CHUNK - strm.avail_out;
+            have = extra - strm.avail_out;
             if (have > 0) {
               if (V_write64(out, 1, (size_t) have, dest) != (size_t) have) {
                 (void) deflateEnd(&strm);
-                return ZLIB_COMPRESS_ERROR;
+                return VAR_WRITE_ERROR;
               }
-              *osize += have;
+              *oSize += have;
             }
         } while (strm.avail_out == 0);
-        if (strm.avail_in != 0)
+        if (strm.avail_in != 0) 
           return ZLIB_COMPRESS_ERROR;
-        remaining -= (OFF_T) mySize;
+        remaining -= iRead;
     } while (flush != Z_FINISH);
-    if (ret != Z_STREAM_END)
+    if (ret != Z_STREAM_END) {
       return ZLIB_COMPRESS_ERROR;
+    }
     (void) deflateEnd(&strm);
     return CDF_OK;
 
@@ -98,18 +102,23 @@ static int defgzip(vFILE *source, vFILE *dest, OFF_T iSize, OFF_T *osize,
    inflate will set the status to end when a full block of compressed data is
    decompressed. infgzip() returns CDF_OK on success, or ZLIB_UNCOMPRESS_ERROR
    for any error, e.g., if memory could not be allocated for processing, 
-   the deflate data is invalid or incomplete, the version of zlib.h and
+   th deflate data is invalid or incomplete, the version of zlib.h and
    the version of the library linked do not match, or there
    is an error reading or writing the files. */
 
-static int infgzip(vFILE *source, OFF_T iSize, vFILE *dest)
+static int infgzip(vFILE *source, OFF_T iSize, vFILE *dest, OFF_T oSize)
 {
     int ret;
     unsigned int have;
     z_stream strm;
     uChar in[CHUNK];
     uChar out[CHUNK];
-    
+    OFF_T iRead, oWrite;
+
+    if (iSize > CHUNK) iRead = CHUNK;
+    else iRead = iSize;
+    if (oSize > CHUNK) oWrite = CHUNK;
+    else oWrite = oSize;
     strm.zalloc = Z_NULL;
     strm.zfree = Z_NULL;
     strm.opaque = Z_NULL;
@@ -118,13 +127,12 @@ static int infgzip(vFILE *source, OFF_T iSize, vFILE *dest)
     ret = inflateInit2(&strm, 15+16);
     if (ret != Z_OK) return ZLIB_UNCOMPRESS_ERROR;
     do {
-        strm.avail_in = (unsigned) V_read64(in, (size_t) 1, (size_t) CHUNK,
-                                            source);
+        strm.avail_in = (unsigned) V_read64(in, (size_t) 1, iRead, source);
         ret = source->eof ? Z_STREAM_END : Z_NO_FLUSH;
         if (strm.avail_in == 0) break;
         strm.next_in = in;
         do {
-            strm.avail_out = CHUNK;
+            strm.avail_out = oWrite;
             strm.next_out = out;
             ret = inflate(&strm, Z_NO_FLUSH);
             if (ret == Z_STREAM_ERROR)
@@ -136,12 +144,12 @@ static int infgzip(vFILE *source, OFF_T iSize, vFILE *dest)
                 (void) inflateEnd(&strm);
                 return ZLIB_UNCOMPRESS_ERROR;
             }
-            have = CHUNK - strm.avail_out;
+            have = oWrite - strm.avail_out;
             if (have > 0) {
-               if (V_write64(out, 1, (size_t) have, dest) != (size_t) have) {
-                 (void) inflateEnd(&strm);
-                 return ZLIB_UNCOMPRESS_ERROR;
-               }
+              if (V_write64(out, 1, (size_t) have, dest) != (size_t) have) {
+                (void) inflateEnd(&strm);
+                return ZLIB_UNCOMPRESS_ERROR;
+              }
             }
         } while (strm.avail_out == 0);
     } while (ret != Z_STREAM_END);
@@ -152,20 +160,20 @@ static int infgzip(vFILE *source, OFF_T iSize, vFILE *dest)
 
 /******************************************************************************
 * CompressGZIP_64.
+* Compress a blocking factor of data pointed by srcOffset with srcSize bytes
+* into RFC1952 gzip format.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CompressGZIP_64 (srcFp, srcOffset, srcSize, srcError,
-                                        destFp, destOffset, destSize,
-                                        destError, level)
-vFILE *srcFp;
-OFF_T srcOffset;
-OFF_T srcSize;
-CDFstatus srcError;
-vFILE *destFp;
-OFF_T destOffset;
-OFF_T *destSize;
-CDFstatus destError;
-Int32 level;
+STATICforIDL CDFstatus CompressGZIP_64 (
+vFILE *srcFp,
+OFF_T srcOffset,
+OFF_T srcSize,
+CDFstatus srcError,
+vFILE *destFp,
+OFF_T destOffset,
+OFF_T *destSize,
+CDFstatus destError,
+Int32 level)
 {
 #if SUPPORT_GZIP64
   CDFstatus pStatus = CDF_OK;
@@ -181,23 +189,25 @@ Int32 level;
 
 /******************************************************************************
 * DecompressGZIP_64.
+* Decompress a CVVR pointed by srcOffset with the iSize bytes in RFC1952 gzip
+* format.
 ******************************************************************************/
 
-STATICforIDL CDFstatus DecompressGZIP_64 (srcFp, srcOffset, iSize, srcError,
-                                          destFp, destOffset, destError)
-vFILE *srcFp;
-OFF_T srcOffset;
-OFF_T iSize;
-CDFstatus srcError;
-vFILE *destFp;
-OFF_T destOffset;
-CDFstatus destError;
+STATICforIDL CDFstatus DecompressGZIP_64 (
+vFILE *srcFp,
+OFF_T srcOffset,
+OFF_T iSize,
+CDFstatus srcError,
+vFILE *destFp,
+OFF_T destOffset,
+OFF_T oSize,
+CDFstatus destError)
 {
 #if SUPPORT_GZIP64
   CDFstatus pStatus = CDF_OK;
   if (!SEEKv64(srcFp,srcOffset,vSEEK_SET)) return srcError;
   if (!SEEKv64(destFp,destOffset,vSEEK_SET)) return destError;
-  if (!sX(infgzip(srcFp,iSize,destFp),&pStatus)) return pStatus;
+  if (!sX(infgzip(srcFp,iSize,destFp,oSize),&pStatus)) return pStatus;
   return pStatus;
 #else
   return UNKNOWN_COMPRESSION;
