@@ -25,7 +25,7 @@
 *				physical record, a temp. buffer is used to cut
 *				down the physical I/Os.
 *   V2.0  29-Jun-04, M Liu      Added LFS (Large File Support > 2G).  
-*				
+*
 ******************************************************************************/
 
 #include "cdflib.h"
@@ -35,11 +35,11 @@
 * HyperRead64.
 ******************************************************************************/
 
-STATICforIDL CDFstatus HyperRead64 (CDF, Var, rd, buffer)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct rdSTRUCT *rd;
-void *buffer;
+STATICforIDL CDFstatus HyperRead64 (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct rdSTRUCT *rd,
+void *buffer)
 {
   Int32 nHypRecValues, nHypRecBytes, nHypDimValues[CDF_MAX_DIMS];
   Logical fullPhyRec, fullPhyDim[CDF_MAX_DIMS];
@@ -55,6 +55,11 @@ void *buffer;
   int dimIncr = 0;              /* How to cycle through the dimensions.  Incr-
 				   ementing (+1) for row-major, decrementing
 				   (-1) for column-major. */
+
+  for (dimN = 0; dimN < CDF_MAX_DIMS; ++dimN) {
+    fullPhyDim[dimN] = FALSE;
+    nHypDimValues[dimN] = 0;
+  }
   /****************************************************************************
   * Determine dimension ordering.
   ****************************************************************************/
@@ -79,6 +84,7 @@ void *buffer;
   * read with a single physical read.  If there are zero dimensions, then this
   * is always true.
   ****************************************************************************/
+  for (dimN = 0; dimN < CDF_MAX_DIMS; ++dimN) fullPhyDim[dimN] = FALSE;
   if (Var->numDims > 0) {
     for (dimN = firstDim; dimN != doneDim; dimN += dimIncr) {
        fullPhyDim[dimN] = TRUE;
@@ -177,28 +183,24 @@ void *buffer;
 *   NOTE: This routine could be called for a record which is virtual.
 ******************************************************************************/
 
-STATICforIDL CDFstatus HyperReadDim64 (numDims, dimSizes, dimVarys, indices,
-				       counts, intervals, nHypDimValues,
-				       nPhyDimValues, fullPhyDim, firstDim,
-				       dimIncr, recNum, offset, buffer,
-				       phyBuffer, CDF, Var)
-Int32 numDims;
-Int32 *dimSizes;
-Int32 *dimVarys;
-Int32 *indices;
-Int32 *counts;
-Int32 *intervals;
-Int32 *nHypDimValues;
-Int32 *nPhyDimValues;
-Logical *fullPhyDim;
-int firstDim;
-int dimIncr;
-Int32 recNum;
-Int32 offset;           /* Byte offset within record. */
-void *buffer;
-void *phyBuffer;
-struct CDFstruct *CDF;
-struct VarStruct *Var;
+STATICforIDL CDFstatus HyperReadDim64 (
+Int32 numDims,
+Int32 *dimSizes,
+Int32 *dimVarys,
+Int32 *indices,
+Int32 *counts,
+Int32 *intervals,
+Int32 *nHypDimValues,
+Int32 *nPhyDimValues,
+Logical *fullPhyDim,
+int firstDim,
+int dimIncr,
+Int32 recNum,
+Int32 offset,           /* Byte offset within record. */
+void *buffer,
+void *phyBuffer,
+struct CDFstruct *CDF,
+struct VarStruct *Var)
 {
   Int32 tOffset; Int32 i; Byte1 *tBuffer; CDFstatus pStatus = CDF_OK;
   OFF_T nValues;
@@ -378,15 +380,15 @@ struct VarStruct *Var;
 * HyperWrite64.
 ******************************************************************************/
 
-STATICforIDL CDFstatus HyperWrite64 (CDF, Var, rd, buffer)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct rdSTRUCT *rd;
-void *buffer;
+STATICforIDL CDFstatus HyperWrite64 (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct rdSTRUCT *rd,
+void *buffer)
 {
   Int32 nHypRecValues, nHypRecBytes, nHypDimValues[CDF_MAX_DIMS];
   Logical fullPhyRec, fullPhyDim[CDF_MAX_DIMS];
-  Int32 firstPhyRec, phyRecN; Byte1 *tBuffer; int dimN; Int32 i;
+  Int32 firstPhyRec, phyRecN; Byte1 *tBuffer; int dimN, dimNt; Int32 i;
   CDFstatus pStatus = CDF_OK; Byte1 *phyBuffer; OFF_T nValues;
   int firstDim = -1;            /* Based on majority, the "highest" dimension
 				   (changes the slowest in memory/on disk). */
@@ -396,6 +398,11 @@ void *buffer;
   int dimIncr = 0;              /* How to cycle through the dimensions.  Incr-
 				   ementing (+1) for row-major, decrementing
 				   (-1) for column-major. */
+
+  for (dimN = 0; dimN < CDF_MAX_DIMS; ++dimN) {
+    fullPhyDim[dimN] = FALSE;
+    nHypDimValues[dimN] = 0;
+  }
   /****************************************************************************
   * Determine dimension ordering.
   ****************************************************************************/
@@ -422,7 +429,6 @@ void *buffer;
   ****************************************************************************/
   if (Var->numDims > 0) {
     for (dimN = firstDim; dimN != doneDim; dimN += dimIncr) {
-       int dimNt;
        fullPhyDim[dimN] = TRUE;
        for (dimNt = dimN; dimNt != doneDim; dimNt += dimIncr)
 	  if ((Var->dimVarys[dimNt] &&
@@ -467,7 +473,6 @@ void *buffer;
   ****************************************************************************/
   if (Var->numDims > 0) {
     for (dimN = firstDim; dimN != doneDim; dimN += dimIncr) {
-       int dimNt;
        nHypDimValues[dimN] = 1;
        for (dimNt = dimN + dimIncr; dimNt != doneDim; dimNt += dimIncr)
 	  nHypDimValues[dimN] *= rd->dimCounts[dimNt];
@@ -592,28 +597,24 @@ void *buffer;
 * HyperWriteDim64.  DANGER, DANGER, I'm recursive.
 ******************************************************************************/
 
-STATICforIDL CDFstatus HyperWriteDim64 (numDims, dimSizes, dimVarys, indices,
-				        counts, intervals, nHypDimValues,
-				        nPhyDimValues, fullPhyDim, firstDim,
-				        dimIncr, recNum, offset, buffer, 
-				 	phyBuffer, CDF, Var)
-Int32 numDims;
-Int32 *dimSizes;
-Int32 *dimVarys;
-Int32 *indices;
-Int32 *counts;
-Int32 *intervals;
-Int32 *nHypDimValues;
-Int32 *nPhyDimValues;
-Logical *fullPhyDim;
-int firstDim;
-int dimIncr;
-Int32 recNum;           /* Record number for this write. */
-Int32 offset;           /* Byte offset within record at which to begin. */
-void *buffer;
-void *phyBuffer;
-struct CDFstruct *CDF;
-struct VarStruct *Var;
+STATICforIDL CDFstatus HyperWriteDim64 (
+Int32 numDims,
+Int32 *dimSizes,
+Int32 *dimVarys,
+Int32 *indices,
+Int32 *counts,
+Int32 *intervals,
+Int32 *nHypDimValues,
+Int32 *nPhyDimValues,
+Logical *fullPhyDim,
+int firstDim,
+int dimIncr,
+Int32 recNum,           /* Record number for this write. */
+Int32 offset,           /* Byte offset within record at which to begin. */
+void *buffer,
+void *phyBuffer,
+struct CDFstruct *CDF,
+struct VarStruct *Var)
 {
   Int32 tOffset; Int32 i; Byte1 *tBuffer;
   CDFstatus pStatus = CDF_OK; OFF_T nValues;
