@@ -22,9 +22,9 @@
 * CDFsav.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFsav (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFsav (
+struct VAstruct *Va,
+struct CurStruct *Cur)
 {
   CDFstatus pStatus = CDF_OK;
   int ix;
