@@ -38,9 +38,9 @@
 * CDFsel.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFsel (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFsel (
+struct VAstruct *Va, 
+struct CurStruct *Cur)
 {
 CDFstatus tStatus, pStatus = CDF_OK;
 switch (Va->item) {
@@ -237,11 +237,31 @@ switch (Va->item) {
   case CDF_CACHESIZE_: {
     struct CDFstruct *CDF;
     int nBuffers = (int) va_arg (Va->ap, long);
+    int num;
     if (nBuffers < 0) return BAD_CACHE_SIZE;
     SelectCDF (Cur->cdf, CDF)
-    CDF->workingCacheSize = BOO(nBuffers > 0,nBuffers,BOO(CDF->singleFile,
-							  NUMcacheSINGLE,
-							  NUMcacheMULTI));
+    if (nBuffers == 0) {
+      if (CDF->singleFile)
+        num = BOO(CDF->workingCacheSize > NUMcacheSINGLE,
+                  CDF->workingCacheSize, NUMcacheSINGLE);
+      else
+        num = BOO(CDF->workingCacheSize > NUMcacheMULTI,
+                  CDF->workingCacheSize, NUMcacheMULTI);
+    } else {
+/*
+      int num2;
+      if (CDF->singleFile)
+        num2 =  BOO (nBuffers > NUMcacheSINGLE, nBuffers, NUMcacheSINGLE);
+      else
+        num2 =  BOO (nBuffers > NUMcacheMULTI, nBuffers, NUMcacheMULTI);
+      num = BOO(CDF->workingCacheSize > num2, CDF->workingCacheSize, num2);
+*/
+      num = BOO(CDF->workingCacheSize==NUMcacheCOMPRESS,
+                BOO(nBuffers>CDF->workingCacheSize,nBuffers,
+                                                   CDF->workingCacheSize),
+                nBuffers);
+    }
+    CDF->workingCacheSize = num;
     if (!CACHEv(CDF->fp,CDF->workingCacheSize)) {
       AbortAccess (CDF, UPDATE, noDELETE);
       return BAD_CACHE_SIZE;
