@@ -40,9 +40,9 @@
 * CDFsel64.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFsel64 (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFsel64 (
+struct VAstruct *Va,
+struct CurStruct *Cur)
 {
 CDFstatus tStatus, pStatus = CDF_OK;
 switch (Va->item) {
