@@ -31,6 +31,7 @@
 *                               is passed in in strcpyX, strcatX, catchrX,
 *                               PstrcatX and PstrcpyX.
 *   V1.9  12-Aug-21, M Liu 	Added a few UTF-8 encoding handling functions.
+*   V1.10 29-Mar-24, M Liu 	Modified strcatX to handle Unicode characters.
 *
 ******************************************************************************/
 
@@ -70,11 +71,11 @@ struct DESCRstruct {
  * NULterminate.  NUL-terminate a character string.
  *****************************************************************************/
 
-STATICforIDL char *NULterminate (string, length, ssh)
-char	*string;			/* String to NUL-terminate. */
-size_t	length;				/* Length of string (not including
+STATICforIDL char *NULterminate (
+char	*string,			/* String to NUL-terminate. */
+size_t	length,				/* Length of string (not including
 					   the NUL terminator. */
-struct STRINGstruct **ssh;		/* Pointer to head of STRINGstruct
+struct STRINGstruct **ssh)		/* Pointer to head of STRINGstruct
 					   linked list. */
 {
   struct STRINGstruct *ss;
@@ -111,8 +112,8 @@ struct STRINGstruct **ssh;		/* Pointer to head of STRINGstruct
  * call.
  *****************************************************************************/
 
-STATICforIDL void FreeStrings (ssh)
-struct STRINGstruct *ssh;		/* Head of STRINGstruct chain. */
+STATICforIDL void FreeStrings (
+struct STRINGstruct *ssh)		/* Head of STRINGstruct chain. */
 {
   struct STRINGstruct *ss, *sst;
   ss = ssh;
@@ -137,11 +138,11 @@ struct STRINGstruct *ssh;		/* Head of STRINGstruct chain. */
  *
  *****************************************************************************/
 
-STATICforIDL Logical isDESCR (ptr, aptr, len)
-void	*ptr;		/* could point to a descriptor or to the
+STATICforIDL Logical isDESCR (
+void	*ptr,		/* could point to a descriptor or to the
 			   string (if already passed by reference) */
-char	**aptr;		/* pointer to string */
-size_t	*len;		/* length of string */
+char	**aptr,		/* pointer to string */
+size_t	*len)		/* length of string */
 {
 #if defined(vms)
   struct dsc$descriptor *tPtr = (struct dsc$descriptor *) ptr;
@@ -174,8 +175,8 @@ size_t	*len;		/* length of string */
  * DESCRtoREF.  Convert from passing by descriptor to passing by reference.
  *****************************************************************************/
 
-STATICforIDL char *DESCRtoREF (ptr)
-void	*ptr;		/* could point to a descriptor or to the string (if
+STATICforIDL char *DESCRtoREF (
+void	*ptr)		/* could point to a descriptor or to the string (if
 			   already passed by reference) */
 {
   char *aptr;		/* pointer to string */
@@ -199,13 +200,13 @@ void	*ptr;		/* could point to a descriptor or to the string (if
  *
  *****************************************************************************/
 
-STATICforIDL char *DESCRtoREFnul (ptr, maxREFlen, ssh)
-void	*ptr;				/* Could point to a descriptor or to
+STATICforIDL char *DESCRtoREFnul (
+void	*ptr,				/* Could point to a descriptor or to
 					   the string (if already passed by
 					   reference). */
-size_t	maxREFlen;			/* Maximum length of the string if
+size_t	maxREFlen,			/* Maximum length of the string if
 					   passed by reference. */
-struct STRINGstruct **ssh;		/* Pointer to head of STRINGstruct
+struct STRINGstruct **ssh)		/* Pointer to head of STRINGstruct
 					   linked list. */
 {
   char *aptr;		/* pointer to string */
@@ -227,10 +228,10 @@ struct STRINGstruct **ssh;		/* Pointer to head of STRINGstruct
  *
  *****************************************************************************/
 
-STATICforIDL char *FindEndNUL (ptr, maxREFlen, ssh)
-char	*ptr;				/* Character string. */
-size_t	maxREFlen;			/* Maximum length of the string. */
-struct STRINGstruct **ssh;		/* Pointer to head of STRINGstruct
+STATICforIDL char *FindEndNUL (
+char	*ptr,				/* Character string. */
+size_t	maxREFlen,			/* Maximum length of the string. */
+struct STRINGstruct **ssh)		/* Pointer to head of STRINGstruct
 					   linked list. */
 {
   size_t i;
@@ -246,9 +247,9 @@ struct STRINGstruct **ssh;		/* Pointer to head of STRINGstruct
  * returned.
  *****************************************************************************/
 
-VISIBLE_PREFIX Logical Trailer (string, trailer)
-char *string;
-char *trailer;
+VISIBLE_PREFIX Logical Trailer (
+char *string,
+char *trailer)
 {
   size_t stringL = strlen (string);
   size_t trailerL = strlen (trailer);
@@ -270,16 +271,15 @@ char *trailer;
  * including the terminating NUL character.
  *****************************************************************************/
 
-VISIBLE_PREFIX char *strcpyX (dst, src, max)
-char *dst;
-char *src;
-size_t max;
+VISIBLE_PREFIX char *strcpyX (
+char *dst,
+char *src,
+size_t max)
 {
   if (max > 0 && src[0] != NUL) {
     size_t j, len;
     len = strlen(src);
     j = MINIMUM(max, len);
-/*    strncpy (dst, src, j); */
     memcpy (dst, src, j);
     dst[(int)j] = NUL;
   } else if (max == 0) {
@@ -292,34 +292,46 @@ size_t max;
 
 /******************************************************************************
  * strcatX.
- *    Concatenates from the source to the destination but only up to the
- * maximum number of characters, 'max', specified. In other words, 'max' is
- * used as a mechanism for controlling how many characters are allowed/stored
- * in the destination. Then NUL-terminates the destination either at the actual
- * end of the concatenated source string or after the maximum number of
- * characters.  If the maximum number of characters is zero, then a normal
- * `strcat' is done. If the maximum number of characters is less than zero, 
- * nothing is concatenated. 'max', if not zero, could be the destination's 
- * actual size, or the maximum allowed size for the destination item defined 
- * in CDF (when the actual size is not available in the calling function), not
- *including the terminating NUL character.
+ *    Concatenates from the source to the destination.
+ *      - byteSrc : number of bytes in string src
+ *      - byteDst : number of allocated bytes in string dst (minus 1 for NUL)
+ *      - usedDst : number of bytes already used in byteDest. 
+ *
+ * If byteDst is 0, 'strcat' is used as dst has enough space for concatenation
+ * from src. If byteDst is negative, nothing is performed.
+ * 
+ * Up to byteDst-usedDst bytes are allowed for concatenation. If src has
+ * more bytes than Dst can hold, only as many "full characters" as possible
+ * can be concatenated to Dst. This is to prevent a portion of a multi-byte
+ * Unicode character being filled to Dst at the end. For this case, Dst's
+ * space might not be fully used.
+ *
  *****************************************************************************/
 
-VISIBLE_PREFIX char *strcatX (dst, src, max)
-char *dst;
-char *src;
-size_t max;
+VISIBLE_PREFIX char *strcatX (
+char *dst,
+char *src,
+size_t byteSrc,
+size_t usedDst,
+size_t byteDst)
 {
-  if (max > 0 && src[0] != NUL) {
-    size_t i, j;
-    i = strlen(dst);
-    j = strlen(src);
-    if (max > i) {
-      size_t k = MINIMUM(max - i, j);
-      if (k > 0) 
-        strncat (dst, src, k);
+  if (byteDst > 0 && src[0] != NUL) {
+    size_t availBytes;
+    availBytes = byteDst - usedDst;
+    if (availBytes >= byteSrc) 
+      strncat (dst, src, byteSrc);
+    else {
+      int numChars, iy, numBytes;
+      numChars = UTF8StrChars (src, (int) byteSrc);
+      for (iy = numChars - 1; iy > -1; --iy) {	
+	numBytes = UTF8CharAtOffset (src, iy);
+	if (availBytes >= numBytes) {
+	  strncat (dst, src, (size_t) numBytes);
+	  break;
+        }
+      }
     }
-  } else if (max == 0) {
+  } else if (byteDst == 0) {
     strcat (dst, src);
   }
   return dst;
@@ -334,10 +346,10 @@ size_t max;
  * concatenated. 
  *****************************************************************************/
 
-VISIBLE_PREFIX char *catchrX (dst, src, max)
-char *dst;
-int src;
-size_t max;
+VISIBLE_PREFIX char *catchrX (
+char *dst,
+int src,
+size_t max)
 {
   size_t l = strlen(dst);
   if (max > 0) {
@@ -361,11 +373,11 @@ size_t max;
  * concatenated. 
  *****************************************************************************/
 
-VISIBLE_PREFIX char *catchrY (dst, src, nbytes, max)
-char *dst;
-char *src;
-size_t nbytes;
-size_t max;
+VISIBLE_PREFIX char *catchrY (
+char *dst,
+char *src,
+size_t nbytes,
+size_t max)
 {
   int ix;
   size_t l = strlen(dst);
@@ -395,10 +407,10 @@ size_t max;
  * destination string exceed a maximum length.
  *****************************************************************************/
 
-VISIBLE_PREFIX char *prependX (dst, src, max)
-char *dst;
-char *src;
-size_t max;
+VISIBLE_PREFIX char *prependX (
+char *dst,
+char *src,
+size_t max)
 {
   size_t lenDst = strlen(dst);
   size_t maxLen = max - lenDst;
@@ -414,10 +426,10 @@ size_t max;
  *****************************************************************************/
 
 #if defined(mac)
-STATICforIDL char *PstrcpyX (dst, src, max)
-char *dst;
-char *src;
-size_t max;
+STATICforIDL char *PstrcpyX (
+char *dst,
+char *src,
+size_t max)
 {
   if (max < 0) return dst;
   int len = (int) BOO(max > 0,MINIMUM(max,(int)src[0]),src[0]);
@@ -433,10 +445,10 @@ size_t max;
 ******************************************************************************/
 
 #if defined(mac)
-STATICforIDL char *PstrcatX (dst, src, max)
-char *dst;
-char *src;
-size_t max;
+STATICforIDL char *PstrcatX (
+char *dst,
+char *src,
+size_t max)
 {
   if (max > 0) {
     int i, j;
@@ -458,10 +470,10 @@ size_t max;
 ******************************************************************************/
 
 #if defined(mac)
-STATICforIDL char *PprependX (dst, src, max)
-char *dst;
-char *src;
-size_t max;
+STATICforIDL char *PprependX (
+char *dst,
+char *src,
+size_t max)
 {
   size_t lenDst = strlen(dst);
   size_t maxLen = max - lenDst;
@@ -477,10 +489,10 @@ size_t max;
  *   Copies a NUL-terminated string (C-style) to a FORTRAN-style string.
  *****************************************************************************/
 
-STATICforIDL void CtoFORTstring (Cstring, FORTstring, length)
-char *Cstring;
-void *FORTstring;
-int length;
+STATICforIDL void CtoFORTstring (
+char *Cstring,
+void *FORTstring,
+int length)
 {
 #if defined(Fif_DESCR)
   char *ptr; size_t lenT; int i;
@@ -503,10 +515,9 @@ int length;
  * Printable.
  *****************************************************************************/
 
-VISIBLE_PREFIX int Printable (c)
-int c;
+VISIBLE_PREFIX int Printable (
+int c)
 {
-  int ret;
   return BOO(IsASCII(c),isprint(c),FALSE); 
 /*
   if (IsASCII(c)) {
@@ -524,17 +535,16 @@ int c;
  * UpperCase.
  *****************************************************************************/
 
-VISIBLE_PREFIX int UpperCase (c)
-int c;
+VISIBLE_PREFIX int UpperCase (
+int c)
 {
   int ret;
-/*  return BOO(IsASCII(c),isupper(c),FALSE); */
   if (IsASCII(c)) {
     ret = isupper(c);
     return (ret!=0?ret:FALSE);
   } else {
     wint_t wc = (wint_t) c;
-    ret = iswupper(c);
+    ret = iswupper(wc);
     return (ret!=0?ret:FALSE);
   }
 }
@@ -543,17 +553,16 @@ int c;
  * LowerCase.
  *****************************************************************************/
 
-VISIBLE_PREFIX int LowerCase (c)
-int c;
+VISIBLE_PREFIX int LowerCase (
+int c)
 {
   int ret;
-/*  return BOO(IsASCII(c),islower(c),FALSE); */
   if (IsASCII(c)) {
     ret = islower(c);
     return (ret!=0?ret:FALSE);
   } else {
     wint_t wc = (wint_t) c;
-    ret = iswlower(c);
+    ret = iswlower(wc);
     return (ret!=0?ret:FALSE);
   }
 }
@@ -562,17 +571,16 @@ int c;
  * Alphabetic.
  *****************************************************************************/
 
-VISIBLE_PREFIX int Alphabetic (c)
-int c;
+VISIBLE_PREFIX int Alphabetic (
+int c)
 {
   int ret;
-/*  return BOO(IsASCII(c),isalpha(c),FALSE); */
   if (IsASCII(c)) {
     ret = isalpha(c);
     return (ret!=0?ret:FALSE);
   } else {
     wint_t wc = (wint_t) c;
-    ret = iswalpha(c);
+    ret = iswalpha(wc);
     return (ret!=0?ret:FALSE);
   }
 }
@@ -581,17 +589,16 @@ int c;
  * Decimal.
  *****************************************************************************/
 
-VISIBLE_PREFIX int Decimal (c)
-int c;
+VISIBLE_PREFIX int Decimal (
+int c)
 {
   int ret;
-/*  return BOO(IsASCII(c),isdigit(c),FALSE); */
   if (IsASCII(c)) {
     ret = isdigit(c);
     return (ret!=0?ret:FALSE);
   } else {
     wint_t wc = (wint_t) c;
-    ret = iswdigit(c);
+    ret = iswdigit(wc);
     return (ret!=0?ret:FALSE);
   }
 }
@@ -600,17 +607,16 @@ int c;
  * Spacing.
  *****************************************************************************/
 
-VISIBLE_PREFIX int Spacing (c)
-int c;
+VISIBLE_PREFIX int Spacing (
+int c)
 {
   int ret;
-/*  return BOO(IsASCII(c),isspace(c),FALSE); */
   if (IsASCII(c)) {
     ret = isspace(c);
     return (ret!=0?ret:FALSE);
   } else {
     wint_t wc = (wint_t) c;
-    ret = iswspace(c);
+    ret = iswspace(wc);
     return (ret!=0?ret:FALSE);
   }
 }
@@ -619,17 +625,16 @@ int c;
  * Visible.
  *****************************************************************************/
 
-VISIBLE_PREFIX int Visible (c)
-int c;
+VISIBLE_PREFIX int Visible (
+int c)
 {
   int ret;
-/*  return BOO(IsASCII(c),isgraph(c),FALSE); */
   if (IsASCII(c)) {
     ret = isgraph(c);
     return (ret!=0?ret:FALSE);
   } else {
     wint_t wc = (wint_t) c; 
-    ret = iswgraph(c);
+    ret = iswgraph(wc);
     return (ret!=0?ret:FALSE);
   }
 }
@@ -638,10 +643,9 @@ int c;
  * MakeLower.
  *****************************************************************************/
 
-VISIBLE_PREFIX int MakeLower (c)
-int c;
+VISIBLE_PREFIX int MakeLower (
+int c)
 {
-/*  return BOO(UpperCase(c),(c | 0x20),c); */
   if (IsASCII(c)) 
     return tolower(c);
   else {
@@ -654,10 +658,9 @@ int c;
  * MakeUpper.
  *****************************************************************************/
 
-VISIBLE_PREFIX int MakeUpper (c)
-int c;
+VISIBLE_PREFIX int MakeUpper (
+int c)
 {
-/*  return BOO(LowerCase(c),(c & 0x5F),c); */
   if (IsASCII(c)) 
     return toupper(c);
   else {
@@ -672,9 +675,9 @@ int c;
  *             0 if compared strings are not same or there is a NULL string
  *****************************************************************************/
 
-int CDFstrcmpIgCase (string1, string2)
-char *string1;
-char *string2;
+int CDFstrcmpIgCase (
+char *string1,
+char *string2)
 {
   size_t string1L, string2L;
   int i;
@@ -694,9 +697,9 @@ char *string2;
  * CDFstrstrIgCase.
  *****************************************************************************/
 
-char *CDFstrstrIgCase (string, substring)
-char *string;
-char *substring;
+char *CDFstrstrIgCase (
+char *string,
+char *substring)
 {
   size_t stringL, substringL;
   int i, j;
@@ -716,11 +719,13 @@ char *substring;
 }
 
 /******************************************************************************
- * UTF8StrLength - Find the number of UTF-8 characters in a given byte length
+ * UTF8StrChars - Find the number of UTF-8 characters in a given byte length
  * string. Returns -1 if this is not a valid UTF-8 string.
  *****************************************************************************/
 
-VISIBLE_PREFIX int UTF8StrLength (const char *string, int byteCnt)
+VISIBLE_PREFIX int UTF8StrChars (
+const char *string, 
+int byteCnt)
 {
   int cnt; unsigned char *p;
   p = UTF8Check ((unsigned char *)string, byteCnt, &cnt);
@@ -731,11 +736,12 @@ VISIBLE_PREFIX int UTF8StrLength (const char *string, int byteCnt)
 }
 
 /******************************************************************************
- * UTF8CharLength - Get the byte length of a character. The argument must be a
- * pointer pointing to the starting byte location of a character
- * (UTF8 unicode).
+ * UTF8CharBytes - Get the byte count of a character. The argument should be a
+ * pointer pointing to the starting byte location of a character in a
+ * Unicode of UTF8 encoding. Otherwise, it returns 0.
  *****************************************************************************/
-VISIBLE_PREFIX int UTF8CharLength (const char *c)
+VISIBLE_PREFIX int UTF8CharBytes (
+const char *c)
 {
   int cnt = 0;
   size_t len;
@@ -752,21 +758,23 @@ VISIBLE_PREFIX int UTF8CharLength (const char *c)
 }
 
 /******************************************************************************
- * UTF8CharAtLength - Get the byte length of a given character in the 
+ * UTF8CharAtBytes - Get the byte count of a given character in the 
  * null-terminating string. The character number is 0-based.  -1 is returned 
  * if the character number is greater than the total number of characters in 
  * the string.
  *****************************************************************************/
-VISIBLE_PREFIX int UTF8CharAtLength (const char *string, int charNum)
+VISIBLE_PREFIX int UTF8CharAtBytes (
+const char *string, 
+int charNum)
 {
   int ix, iy, iz, loc;
   iz = (int) strlen (string);
-  ix = UTF8StrLength (string, iz);
+  ix = UTF8StrChars (string, iz);
   if (charNum > ix) return -1;
   ix = -1;
   iy = loc = 0;
   while (ix < charNum) {
-    iy = UTF8CharLength (string+loc);
+    iy = UTF8CharBytes (string+loc);
     ++ix;
     loc += iy;
   }
@@ -780,36 +788,40 @@ VISIBLE_PREFIX int UTF8CharAtLength (const char *string, int charNum)
  * character string, it is not. if the total number of characters is less than
  * the given character number, -1 is returned.
  *****************************************************************************/
-VISIBLE_PREFIX int UTF8CharAtOffset (const char *string, int charNum)
+VISIBLE_PREFIX int UTF8CharAtOffset (
+const char *string,
+int charNum)
 {
   int ix, iy, i, j, len;
   iy = (int) strlen (string);
-  ix = UTF8StrLength (string, iy);
+  ix = UTF8StrChars (string, iy);
   j = 0;
   if (charNum > ix) return -1;
   for (i = 0; i < charNum; ++i) {
-    len = UTF8CharLength (string+j);
+    len = UTF8CharBytes (string+j);
     j += len;
   }
   return j;
 }
 
 /******************************************************************************
- * UTF8CharAtOffset - find the byte location in the null-terminating string 
+ * UTF8CharAtString - find the pointer location in the null-terminating string 
  * for a given character number (0-based). For an ASCII string, it is the same
  * as the character number. For multi-byte character string, it is not. if the
  * total number of characters is less than the given character number, NULL is 
  * returned.
 ******************************************************************************/
-VISIBLE_PREFIX char *UTF8CharAtString (const char *string, int charNum)
+VISIBLE_PREFIX char *UTF8CharAtString (
+const char *string, 
+int charNum)
 {
   int ix, iy, i, j, len;
   iy = (int) strlen (string);
-  ix = UTF8StrLength (string, iy);
+  ix = UTF8StrChars (string, iy);
   j = 0;
   if (charNum > ix) return NULL;
   for (i = 0; i < charNum; ++i) {
-    len = UTF8CharLength (string+j);
+    len = UTF8CharBytes (string+j);
     j += len;
   }
   return ((char *)string)+j;
@@ -819,17 +831,19 @@ VISIBLE_PREFIX char *UTF8CharAtString (const char *string, int charNum)
  * UTF8ByteLengthFromCharAt - Get the remaining byte length in the 
  * null-terminating string from the given character number (0-based).
  *****************************************************************************/
-VISIBLE_PREFIX int UTF8ByteLengthFromCharAt (const char *string, int charNum)
+VISIBLE_PREFIX int UTF8ByteLengthFromCharAt (
+const char *string, 
+int charNum)
 {
   int ix, iy, iz, loc;
   iz = strlen(string);
   if (charNum <= 0) return iz;
-  ix = UTF8StrLength (string, iz);
+  ix = UTF8StrChars (string, iz);
   if (charNum > ix) return 0;
   ix = 0;
   iy = loc = 0;
   while (ix < charNum) {
-    iy = UTF8CharLength (string+loc);
+    iy = UTF8CharBytes (string+loc);
     loc += iy;
     ++ix;
   }
@@ -837,15 +851,17 @@ VISIBLE_PREFIX int UTF8ByteLengthFromCharAt (const char *string, int charNum)
 }
 
 /******************************************************************************
- * UTF8StrLengthFromCharAt - Find the remaining number of charatcers in the
+ * UTF8StrCharsFromCharAt - Find the remaining number of charatcers in the
  * null-terminating string from the given character number (0-based),
  * inclusive.
  *****************************************************************************/
-VISIBLE_PREFIX int UTF8StrLengthFromCharAt (const char *string, int charNum)
+VISIBLE_PREFIX int UTF8StrCharsFromCharAt (
+const char *string, 
+int charNum)
 {
    int ix, iy, i;
    iy = (int) strlen(string);
-   ix = UTF8StrLength (string, iy);
+   ix = UTF8StrChars (string, iy);
    i = ix - charNum;
    if (i < 0) i = 0;
    return i;
@@ -870,7 +886,10 @@ VISIBLE_PREFIX int UTF8StrLengthFromCharAt (const char *string, int charNum)
  * SPDX-License-Identifier: Unlicense
  *****************************************************************************/
 
-VISIBLE_PREFIX int UnicodetoUTF8 (char *utf8, int *codepoints, int numCP)
+VISIBLE_PREFIX int UnicodetoUTF8 (
+char *utf8, 
+int *codepoints, 
+int numCP)
 {
   int i, bytePtr, size, cp;
 
@@ -927,7 +946,10 @@ VISIBLE_PREFIX int UnicodetoUTF8 (char *utf8, int *codepoints, int numCP)
  *  SPDX-License-Identifier: Unlicense
  *****************************************************************************/
 
-int UTF8toUnicode(int *codepoints, const char *utf8, int byteCnt)
+int UTF8toUnicode (
+int *codepoints, 
+const char *utf8, 
+int byteCnt)
 {
   int x, y, z, kk, tmp;
 
@@ -994,8 +1016,10 @@ int UTF8toUnicode(int *codepoints, const char *utf8, int byteCnt)
  * Added the number of bytes to check in the string. If it is 0, the full
  * string is checked. 
  *****************************************************************************/
-VISIBLE_PREFIX unsigned char *UTF8Check(unsigned char *s, int numBytes,
-	                         	int* charCnt)
+VISIBLE_PREFIX unsigned char *UTF8Check (
+unsigned char *s, 
+int numBytes,
+int* charCnt)
 {
   int i;
   i = 0;
@@ -1073,12 +1097,15 @@ VISIBLE_PREFIX unsigned char *UTF8Check(unsigned char *s, int numBytes,
  *   Markus Kuhn <http://www.cl.cam.ac.uk/~mgk25/> -- 2005-03-30
  *   License: http://www.cl.cam.ac.uk/~mgk25/short-license.html
  *****************************************************************************/
-VISIBLE_PREFIX int IsUTF8Char(const char *s)
+VISIBLE_PREFIX int IsUTF8Char (
+const char *s)
 {
-  
   if ((int)(unsigned char)*s < 0x80) {
     /* 0xxxxxxx */
-    return 1;
+    if (Printable((int)*s))
+      return 1;
+    else 
+      return 0;
   } else if ((int) (unsigned char) (s[0] & 0xe0) == 0xc0) {
     /* 110XXXXx 10xxxxxx */
     if ((int) (unsigned char) (s[1] & 0xc0) != 0x80 ||
@@ -1115,7 +1142,6 @@ VISIBLE_PREFIX int IsUTF8Char(const char *s)
       return 1;;
   } else
     return 0;
-
 }
 
 /******************************************************************************
@@ -1124,9 +1150,9 @@ VISIBLE_PREFIX int IsUTF8Char(const char *s)
 ******************************************************************************/
 
 #if defined(SunOSpre41)
-/*STATICforIDL*/ char *strstr (string, substring)
-char *string;
-char *substring;
+/*STATICforIDL*/ char *strstr (
+char *string,
+char *substring)
 {
   int stringL = strlen(string);
   int substringL = strlen(substring);
