@@ -38,18 +38,9 @@
 #define HOURinNanoSecs          3600000000000LL
 #define MINUTEinNanoSecs        60000000000LL
 #define T12hinNanoSecs          43200000000000LL
-/* Julian days for 1707-09-22T12:12:10.961224192 and
- * 2292-04-11T11:46:07.670775807, the valid TT2000 range. */
-/* 1707-09-22T12:12:10.961224192 reserved as FILLVAL */
-/*                               (encoded as 9999-12-31T23:59:59.999999999) */
-/* 1707-09-22T12:12:10.961224193 reserved as PADVAL */
-/*                               (encoded as 0000-01-01T00:00:00.000000000) */
-/* 1707-09-22T12:12:10.961224195 reserved as ILLEGAL_VAL */
-/*                               (encoded as 9999-12-31T23:59:59.999999999) */
+/* Julian days for 1707-09-22 and 2292-04-11, the valid TT2000 range. */
 #define JDY17070922             2344793
-#define JDY17070922subdayns     43930961224192LL
 #define JDY22920411             2558297
-#define JDY22920411subdayns     42367670775807LL
 
 /* Number of Delta(dAT) expressions before leap seconds were introduced */
 #define NERA1 14
@@ -159,15 +150,15 @@ static int MonthNumber (char *);
 static int ScanUTCstring (char *);
 static double LeapSecondsfromYMD (long, long, long);
 static double LeapSecondsfromJ2000 (long long, int *);
-static void LoadLeapSecondsTable ();
-static void LoadLeapNanoSecondsTable ();
+static void LoadLeapSecondsTable (void);
+static void LoadLeapNanoSecondsTable (void);
 static void EPOCHbreakdownTT2000 (double, long *, long *, long *, long *,
                                   long *, long *);
 static int LeapSecondLastUpdatedinTable (int);
 static void FromUTCISO8601string (char *string, long *ly, long *lm, long *ld, 
                                   long *lh, long *ln, long *ls,
                                   long *ll, long *lu, long *la);
-static void RecheckLeapSecondsTableEnvVar ();
+static void RecheckLeapSecondsTableEnvVar (void);
 
 static char *MonthToken (long month)
 {
@@ -206,14 +197,21 @@ static int MonthNumber (char *month)
 }
 
 
-static double JulianDay12h (long y, long m, long d)
+static double JulianDay12h (
+long y, 
+long m, 
+long d)
 {
   if (m == 0) m = 1;
   return
    (double) (367*y-7*(y+(m+9)/12)/4-3*((y+(m-9)/7)/100+1)/4+275*m/9+d+1721029);
 }
 
-static void DatefromJulianDay (double julday, long *y, long *m, long *d)
+static void DatefromJulianDay (
+double julday, 
+long *y, 
+long *m, 
+long *d)
 {
   long i, j, k, l, n;
   l=68569 + (long) julday;
@@ -232,7 +230,8 @@ static void DatefromJulianDay (double julday, long *y, long *m, long *d)
   return; 
 }
 
-static int ScanUTCstring (char *string) 
+static int ScanUTCstring (
+char *string) 
 {
   int len; long tmp;
   len = (int) strlen (string);
@@ -256,7 +255,10 @@ static int ScanUTCstring (char *string)
   return -1;
 }
 
-static int ValidateYMD (long yy, long mm, long dd)
+static int ValidateYMD (
+long yy, 
+long mm, 
+long dd)
 {
   double jday;
   if (yy <= 0 || mm < 0 || dd < 0) return 0;
@@ -266,8 +268,14 @@ static int ValidateYMD (long yy, long mm, long dd)
   return 1; 
 }
 
-void EPOCHbreakdownTT2000 (double epoch, long *year, long *month, long *day,
-                           long *hour, long *minute, long *second)
+void EPOCHbreakdownTT2000 (
+double epoch, 
+long *year, 
+long *month, 
+long *day,
+long *hour, 
+long *minute, 
+long *second)
 {
   long jd,i,j,k,l,n;
   double second_AD, minute_AD, hour_AD, day_AD;
@@ -299,7 +307,7 @@ void EPOCHbreakdownTT2000 (double epoch, long *year, long *month, long *day,
   return;
 }
 
-static void LoadLeapSecondsTable ()
+static void LoadLeapSecondsTable (void)
 {
 
   if (tableChecked == 0) {
@@ -309,7 +317,7 @@ static void LoadLeapSecondsTable ()
     table = CDFgetLeapSecondsTableEnvVar();
     if (table != NULL && strlen(table) > 0) {
       size_t len = strlen(table);
-      leapTableEnv = (char *) malloc (len + 1);
+      leapTableEnv = (char *) cdf_AllocateMemory (len + 1, NULL);
       strcpyX (leapTableEnv, table, len);
       leaptable = fopen (table, "r");
       if (leaptable != NULL) {
@@ -370,7 +378,7 @@ static void LoadLeapSecondsTable ()
   }
 }
 
-static void LoadLeapNanoSecondsTable () 
+static void LoadLeapNanoSecondsTable (void) 
 {
   int ix;
   double diffLeap;
@@ -405,7 +413,10 @@ static void LoadLeapNanoSecondsTable ()
   }
 }
 
-static double LeapSecondsfromYMD (long iy, long im, long id)
+static double LeapSecondsfromYMD (
+long iy, 
+long im, 
+long id)
 {
   int i, j;
   long m, n;
@@ -431,7 +442,9 @@ static double LeapSecondsfromYMD (long iy, long im, long id)
   return da;
 }
 
-static double LeapSecondsfromJ2000 (long long nanosecs, int *leapSecond)
+static double LeapSecondsfromJ2000 (
+long long nanosecs, 
+int *leapSecond)
 {
   int i, j;
   double da;
@@ -455,7 +468,7 @@ static double LeapSecondsfromJ2000 (long long nanosecs, int *leapSecond)
   return da;
 }
 
-static void RecheckLeapSecondsTableEnvVar ()
+static void RecheckLeapSecondsTableEnvVar (void)
 {
   char *table2;
   if (openCDF64s != 0) return;
@@ -465,7 +478,7 @@ static void RecheckLeapSecondsTableEnvVar ()
         strcmp (leapTableEnv, table2) != 0) {
         size_t len = strlen(table2);
         CDFClearLeapSecondsTable();
-        leapTableEnv = (char *) malloc (len + 1);
+        leapTableEnv = (char *) cdf_AllocateMemory (len + 1, NULL);
         strcpyX (leapTableEnv, table2, len);
         LoadLeapSecondsTable();
     }
@@ -480,7 +493,7 @@ static void RecheckLeapSecondsTableEnvVar ()
 * CDFgetLeapSecondsTableEnvVar.
 ******************************************************************************/
     
-VISIBLE_PREFIX char *CDFgetLeapSecondsTableEnvVar ()
+VISIBLE_PREFIX char *CDFgetLeapSecondsTableEnvVar (void)
 {
     if (openCDF64s > 0) return leapTableEnv;
     else {
@@ -496,7 +509,7 @@ VISIBLE_PREFIX char *CDFgetLeapSecondsTableEnvVar ()
 * CDFClearLeapSecondsTable.
 ******************************************************************************/
     
-VISIBLE_PREFIX void CDFClearLeapSecondsTable ()
+VISIBLE_PREFIX void CDFClearLeapSecondsTable (void)
 {
   int ix;
   if (openCDF64s == 0 && LTD != NULL) {
@@ -511,7 +524,7 @@ VISIBLE_PREFIX void CDFClearLeapSecondsTable ()
     tableChecked  = 0;
   }
   if (openCDF64s == 0 && leapTableEnv != NULL) {
-    free (leapTableEnv);
+    cdf_FreeMemory (leapTableEnv, NULL);
     leapTableEnv = NULL;
   }
 }
@@ -520,7 +533,8 @@ VISIBLE_PREFIX void CDFClearLeapSecondsTable ()
 * CDFfillLeapSecondsTable.
 ******************************************************************************/
 
-VISIBLE_PREFIX void CDFfillLeapSecondsTable (double **table)
+VISIBLE_PREFIX void CDFfillLeapSecondsTable (
+double **table)
 {
   int ix;
   if (LTD == NULL) LoadLeapSecondsTable();
@@ -539,7 +553,7 @@ VISIBLE_PREFIX void CDFfillLeapSecondsTable (double **table)
 * CDFgetRowsinLeapSecondsTable.
 ******************************************************************************/
 
-VISIBLE_PREFIX int CDFgetRowsinLeapSecondsTable ()
+VISIBLE_PREFIX int CDFgetRowsinLeapSecondsTable (void)
 {
   if (LTD == NULL) LoadLeapSecondsTable();
   else RecheckLeapSecondsTableEnvVar();
@@ -550,11 +564,15 @@ VISIBLE_PREFIX int CDFgetRowsinLeapSecondsTable ()
 * CDFgetLastDateinLeapSecondsTable.
 ******************************************************************************/
 #if defined(vms)      
-VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTBL (long *year, long *month, 
-                                                    long *day)
+VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTBL (
+long *year, 
+long *month, 
+long *day)
 #else
-VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTable (long *year, long *month,
-                                                      long *day)
+VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTable (
+long *year, 
+long *month,
+long *day)
 #endif
 {
   if (LTD == NULL) LoadLeapSecondsTable();
@@ -568,7 +586,7 @@ VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTable (long *year, long *month,
 * CDFgetLeapSecondsTableStatus.
 ******************************************************************************/
       
-VISIBLE_PREFIX int CDFgetLeapSecondsTableStatus ()
+VISIBLE_PREFIX int CDFgetLeapSecondsTableStatus (void)
 {
   if (LTD == NULL) LoadLeapSecondsTable();
   else RecheckLeapSecondsTableEnvVar();
@@ -580,11 +598,15 @@ VISIBLE_PREFIX int CDFgetLeapSecondsTableStatus ()
 ******************************************************************************/
 
 #if defined(STDARG)
-VISIBLE_PREFIX void breakdownTT2000 (long long nanoSecSinceJ2000,
-                                     double *ly, double *lm,
-                                     double *ld, ...)
+VISIBLE_PREFIX void breakdownTT2000 (
+long long nanoSecSinceJ2000,
+double *ly, 
+double *lm,
+double *ld, 
+...)
 #else
-VISIBLE_PREFIX void breakdownTT2000 (va_alist)
+VISIBLE_PREFIX void breakdownTT2000 (
+va_alist)
 va_dcl
 #endif
 {
@@ -605,6 +627,7 @@ va_dcl
   lm = va_arg (ap, double *);
   ld = va_arg (ap, double *);
 #endif
+  for (ix = 0; ix < 6; ++ix) opt[ix] = NULL;
   ix = 0;
   tmp = va_arg (ap, double *);
   while (tmp != TT2000NULL) {
@@ -778,11 +801,17 @@ va_dcl
 * Otherwise, it returns the same value as CDF_TT2000_from_UTC_parts.
 ******************************************************************************/
 
-VISIBLE_PREFIX long long computeTT2000withBasedLeapDay (long yy, long mm, 
-                                                        long dd, long hh,
-                                                        long mn, long ss,
-                                                        long ms, long us,
-                                                        long ns, int yymmdd)
+VISIBLE_PREFIX long long computeTT2000withBasedLeapDay (
+long yy, 
+long mm, 
+long dd, 
+long hh,
+long mn, 
+long ss,
+long ms, 
+long us,
+long ns, 
+int yymmdd)
 {
   long long nanoSecSinceJ2000;
   if (yy < 0 || mm < 0 || dd < 0 || hh < 0 || mn < 0 ||
@@ -816,12 +845,18 @@ VISIBLE_PREFIX long long computeTT2000withBasedLeapDay (long yy, long mm,
 * necessay if its value crosses over the next new leap second day in the LST. 
 ******************************************************************************/
 
-VISIBLE_PREFIX void breakdownTT2000withBasedLeapDay (long long tt2000,
-                                                     int yymmdd, long *yy,
-                                                     long *mm, long *dd,
-                                                     long *hh, long *mn,
-                                                     long *ss, long *ms,
-                                                     long *us, long *ns)
+VISIBLE_PREFIX void breakdownTT2000withBasedLeapDay (
+long long tt2000,
+int yymmdd, 
+long *yy,
+long *mm, 
+long *dd,
+long *hh, 
+long *mn,
+long *ss, 
+long *ms,
+long *us, 
+long *ns)
 {
   long long *tmpTT2000s;
   double yyy, mmm, ddd, hhh, mmn, sss, mms, mus, mns;
@@ -838,7 +873,8 @@ VISIBLE_PREFIX void breakdownTT2000withBasedLeapDay (long long tt2000,
 		       &mus, &mns);
     else {
       found = 0;
-      tmpTT2000s = (long long *) malloc (sizeof (long long) * off);
+      tmpTT2000s = (long long *) cdf_AllocateMemory (sizeof (long long) * off,
+                                                     NULL);
       for (iy = 0; iy < off; ++iy)
         tmpTT2000s[iy] = computeTT2000withBasedLeapDay (LTD[ix+1+iy][0],
                                                         LTD[ix+1+iy][1],
@@ -856,7 +892,7 @@ VISIBLE_PREFIX void breakdownTT2000withBasedLeapDay (long long tt2000,
       if (found == 0)
         breakdownTT2000 (tt2000, &yyy, &mmm, &ddd, &hhh, &mmn, &sss, &mms,
                          &mus, &mns);
-      free (tmpTT2000s);
+      cdf_FreeMemory (tmpTT2000s, NULL);
       tmpTT2000s = NULL;
     }
   }
@@ -884,8 +920,10 @@ VISIBLE_PREFIX void breakdownTT2000withBasedLeapDay (long long tt2000,
 * necessay if its value crosses over the next new leap second day in the LST.
 ******************************************************************************/
 
-VISIBLE_PREFIX void encodeTT2000withBasedLeapDay (long long tt2000,
-                                                  int yymmdd, char *string)
+VISIBLE_PREFIX void encodeTT2000withBasedLeapDay (
+long long tt2000,
+int yymmdd, 
+char *string)
 {
   long long *tmpTT2000s;
   int off, ix, iy, found;
@@ -900,7 +938,8 @@ VISIBLE_PREFIX void encodeTT2000withBasedLeapDay (long long tt2000,
     return;
   } else {
     found = 0;
-    tmpTT2000s = (long long *) malloc (sizeof (long long) * off);
+    tmpTT2000s = (long long *) cdf_AllocateMemory (sizeof (long long) * off,
+                                                   NULL);
     for (iy = 0; iy < off; ++iy)
       tmpTT2000s[iy] = computeTT2000withBasedLeapDay (LTD[ix+1+iy][0],
                                                       LTD[ix+1+iy][1],
@@ -917,7 +956,7 @@ VISIBLE_PREFIX void encodeTT2000withBasedLeapDay (long long tt2000,
     }
     if (found == 0)
       CDF_TT2000_to_UTC_string (tt2000, string, 3);
-    free (tmpTT2000s);
+    cdf_FreeMemory (tmpTT2000s, NULL);
     tmpTT2000s = NULL;
   }
   return;
@@ -936,7 +975,9 @@ VISIBLE_PREFIX void encodeTT2000withBasedLeapDay (long long tt2000,
 * necessay if its day crosses over the next new leap second day in the LST.
 ******************************************************************************/
 
-VISIBLE_PREFIX long long parseTT2000withBasedLeapDay (char *tt2000, int yymmdd)
+VISIBLE_PREFIX long long parseTT2000withBasedLeapDay (
+char *tt2000, 
+int yymmdd)
 {
   long yy, mm, dd, hh, mn, ss, ms = 0L, us = 0L, ns = 0L;
   FromUTCISO8601string (tt2000, &yy, &mm, &dd, &hh, &mn, &ss, &ms, &us, &ns);
@@ -951,10 +992,14 @@ VISIBLE_PREFIX long long parseTT2000withBasedLeapDay (char *tt2000, int yymmdd)
 ******************************************************************************/
 
 #if defined(STDARG)
-VISIBLE_PREFIX long long computeTT2000 (double yy, double mm, 
-                                        double dd, ...)
+VISIBLE_PREFIX long long computeTT2000 (
+double yy, 
+double mm, 
+double dd, 
+...)
 #else
-VISIBLE_PREFIX long long computeTT2000 (va_alist)
+VISIBLE_PREFIX long long computeTT2000 (
+va_alist)
 va_dcl
 #endif
 {
@@ -968,7 +1013,7 @@ va_dcl
   long lyl, lml, ldl, lhl, lnl, lsl, lll, lul, lal;
   long xy, xm, xd;
   int  lyear;
-  double jday12h = 0.0;
+
 #if defined(STDARG)
   va_start (ap, dd);
 #else
@@ -978,6 +1023,7 @@ va_dcl
   mm = va_arg (ap, double);
   dd = va_arg (ap, double);
 #endif
+  for (ix = 0; ix < 6; ++ix) opt[ix] = 0.0;
   ix = 0;
   tmp = va_arg (ap, double);
   while (tmp != TT2000END) {
@@ -1093,7 +1139,7 @@ va_dcl
       lh = ln = ls = ll = lu = la = 0.0;
     }
   }
-  lyl = lml = -999;
+  lyl = lml = ldl = -999;
   if (la >= 1000.0) {
     double ad, ah, am, as, al, au;
     ad = floor(la / 86400000000000.0);
@@ -1114,8 +1160,8 @@ va_dcl
     ls += as;
     ll += al; 
     lu += au;
-    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
+    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
   } 
   if (lu >= 1000.0) {
     double ad, ah, am, as, al;
@@ -1134,8 +1180,8 @@ va_dcl
     ln += am;
     ls += as;
     ll += al;
-    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
+    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
   }
   if (ll >= 1000.0) {
     double ad, ah, am, as;
@@ -1151,8 +1197,8 @@ va_dcl
     lh += ah;
     ln += am;
     ls += as;
-    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
+    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
   }
   if (ls >= 60.0) {
     tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
@@ -1170,8 +1216,8 @@ va_dcl
       ld += ad;
       lh += ah;
       ln += am;
-      jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
-      DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
+      tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
+      DatefromJulianDay (tmp, &lyl, &lml, &ldl);
     }
   }
   if (ln >= 60.0) {
@@ -1182,18 +1228,18 @@ va_dcl
     ln = ln - ah * 60;
     ld += ad;
     lh += ah;
-    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
+    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
   }
   if (lh >= 24.0) {
     double ad;
     ad = floor(lh / 24.0); 
     lh = lh - ad * 24.0;
     ld += ad;
-    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
+    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
   }
-  if (lyl == -999 && lml == -999) {
+  if (lyl == -999 && lml == -999 && ldl == -999) {
     lyl = (long) ly;
     lml = (long) lm;
     ldl = (long) ld;
@@ -1213,16 +1259,6 @@ va_dcl
     return DEFAULT_TT2000_PADVALUE;
   if (!YearWithin(lyl) && !ValidateYMD(lyl,lml,ldl))
     return ILLEGAL_TT2000_VALUE;
-  if (jday12h == 0.0)  jday12h = JulianDay12h (lyl, lml, ldl);
-  if (jday12h == JDY22920411) {
-    long long subday = (long long) (3600*lhl+60*lnl+lsl)*1000000000LL+
-                       lll*1000000LL+lul*1000LL+lal;
-    if (subday > JDY22920411subdayns) return ILLEGAL_TT2000_VALUE;
-  } else if (jday12h == JDY17070922) {
-    long long subday = (long long) (3600*lhl+60*lnl+lsl)*1000000000LL+
-                       lll*1000000LL+lul*1000LL+lal;
-    if (subday < JDY17070922subdayns) return ILLEGAL_TT2000_VALUE;
-  }
   lyear = (lyl & 3) == 0 && ((lyl % 25) != 0 || (lyl & 15) == 0);
   if ((!lyear && ldl > 365) || (lyear && ldl > 366))
     return ILLEGAL_TT2000_VALUE;
@@ -1273,7 +1309,8 @@ va_dcl
 * CDF_TT2000_to_UTC_EPOCH.
 ******************************************************************************/
 
-VISIBLE_PREFIX double CDF_TT2000_to_UTC_EPOCH (long long nanoSecSinceJ2000)
+VISIBLE_PREFIX double CDF_TT2000_to_UTC_EPOCH (
+long long nanoSecSinceJ2000)
 {
   double yy, mm, dd, hh, nn, ss, ll, uu, aa;
   double epoch;
@@ -1291,7 +1328,8 @@ VISIBLE_PREFIX double CDF_TT2000_to_UTC_EPOCH (long long nanoSecSinceJ2000)
 * CDF_TT2000_from_UTC_EPOCH.
 ******************************************************************************/
 
-VISIBLE_PREFIX long long CDF_TT2000_from_UTC_EPOCH (double epoch)
+VISIBLE_PREFIX long long CDF_TT2000_from_UTC_EPOCH (
+double epoch)
 {
   long yy, mm, dd, hh, nn, ss, ll;
   if (epoch == -1.0E31 || epoch == -1.0E-31)
@@ -1309,8 +1347,9 @@ VISIBLE_PREFIX long long CDF_TT2000_from_UTC_EPOCH (double epoch)
 * CDF_TT2000_to_UTC_EPOCH16.
 ******************************************************************************/
 
-VISIBLE_PREFIX double CDF_TT2000_to_UTC_EPOCH16 (long long nanoSecSinceJ2000,
-                                                 double *epoch)
+VISIBLE_PREFIX double CDF_TT2000_to_UTC_EPOCH16 (
+long long nanoSecSinceJ2000,
+double *epoch)
 {
   double yy, mm, dd, hh, nn, ss, ll, uu, aa;
   double tmp;
@@ -1336,7 +1375,8 @@ VISIBLE_PREFIX double CDF_TT2000_to_UTC_EPOCH16 (long long nanoSecSinceJ2000,
 * CDF_TT2000_from_UTC_EPOCH16.
 ******************************************************************************/
 
-VISIBLE_PREFIX long long CDF_TT2000_from_UTC_EPOCH16 (double *epoch)
+VISIBLE_PREFIX long long CDF_TT2000_from_UTC_EPOCH16 (
+double *epoch)
 {
   long yy, mm, dd, hh, nn, ss, ll, uu, aa, pp;
   if (epoch[0] == 0.0 && epoch[1] == 0.0) return DEFAULT_TT2000_PADVALUE;
@@ -1361,8 +1401,10 @@ VISIBLE_PREFIX long long CDF_TT2000_from_UTC_EPOCH16 (double *epoch)
 * Style 4: yyyy-mm-ddThh:mn:ss.mmmuuunnnZ as 9999-12-31T23:59:59.999999999Z
 ******************************************************************************/
 
-VISIBLE_PREFIX void toEncodeTT2000 (long long nanoSecSinceJ2000,
-                                    int style, char *string)
+VISIBLE_PREFIX void toEncodeTT2000 (
+long long nanoSecSinceJ2000,
+int style, 
+char *string)
 {
    if (style < 0 || style > 4) style = 3;
    encodeTT2000 (nanoSecSinceJ2000, string, style);
@@ -1373,17 +1415,13 @@ VISIBLE_PREFIX void toEncodeTT2000 (long long nanoSecSinceJ2000,
 ******************************************************************************/
 
 #if defined(STDARG)
-/*
-VISIBLE_PREFIX void CDF_TT2000_to_UTC_string (long long nanoSecSinceJ2000,
-                                              char *string, ...)
-*/
-VISIBLE_PREFIX void encodeTT2000 (long long nanoSecSinceJ2000,
-                                  char *string, ...)
+VISIBLE_PREFIX void encodeTT2000 (
+long long nanoSecSinceJ2000,
+char *string, 
+...)
 #else
-/*
-VISIBLE_PREFIX void CDF_TT2000_to_UTC_string (va_alist)
-*/
-VISIBLE_PREFIX void encodeTT2000 (va_alist)
+VISIBLE_PREFIX void encodeTT2000 (
+va_alist)
 va_dcl
 #endif
 {
@@ -1505,7 +1543,8 @@ va_dcl
 *
 ******************************************************************************/
 
-VISIBLE_PREFIX long long toParseTT2000 (char *string)
+VISIBLE_PREFIX long long toParseTT2000 (
+char *string)
 {
   return parseTT2000(string);
 }
@@ -1515,12 +1554,13 @@ VISIBLE_PREFIX long long toParseTT2000 (char *string)
 * parseTT2000 (aka CDF_TT2000_from_UTC_string).
 ******************************************************************************/
 
-VISIBLE_PREFIX long long parseTT2000 (char *string)
+VISIBLE_PREFIX long long parseTT2000 (
+char *string)
 {
   double fraction;
   long ly, lm, ld, lh, ln, ls, ll, lu, la;
   int  len, style, is, ie;
-  char *tmpPtr, *end;
+  char *tmpPtr;
 
   ll = lu = la = 0L;
   is = ie = 0;
@@ -1530,7 +1570,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
   while(isspace((unsigned char)*(string+len-ie-1)) ||
         !isprint((unsigned char)*(string+len-ie-1))) ie++;
   len = len - is - ie;
-  tmpPtr = (char *) malloc ((size_t)len+1);
+  tmpPtr = (char *) cdf_AllocateMemory ((size_t)len+1, NULL);
   memcpy (tmpPtr, string+is, (size_t)len);
   *(tmpPtr+len) = (char) '\0';
   style = ScanUTCstring(tmpPtr);
@@ -1541,7 +1581,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     len = (int) strlen(tmpPtr);
     if (len != TT2000_0_STRING_LEN) {
       int ix;
-      newstr = (char *) malloc (TT2000_0_STRING_LEN+1);
+      newstr = (char *) cdf_AllocateMemory (TT2000_0_STRING_LEN+1, NULL);
       for (ix = 0; ix < TT2000_0_STRING_LEN+1; ++ix) newstr[ix] = '0';
       newstr[TT2000_0_STRING_LEN] = '\0';
       if (tmpPtr[len-1] == 'Z' || tmpPtr[len-1] == 'z') --len;
@@ -1550,8 +1590,8 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
       if (sscanf(newstr,"%2ld-%c%c%c-%4ld %2ld:%2ld:%2ld.%9ld",
           &ld, &(moString[0]), &(moString[1]), &(moString[2]), &ly,
           &lh, &ln, &ls, &tmp) < 8) {
-         free (newstr);
-         free (tmpPtr);
+         cdf_FreeMemory (newstr, NULL);
+         cdf_FreeMemory (tmpPtr, NULL);
          newstr = NULL;
          tmpPtr = NULL;
          return ILLEGAL_TT2000_VALUE;
@@ -1560,7 +1600,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
       if (sscanf(tmpPtr,"%2ld-%c%c%c-%4ld %2ld:%2ld:%2ld.%9ld",
           &ld, &(moString[0]), &(moString[1]), &(moString[2]), &ly,
           &lh, &ln, &ls, &tmp) != 9) {
-        free (tmpPtr);
+        cdf_FreeMemory (tmpPtr, NULL);
         tmpPtr = NULL;
         return ILLEGAL_TT2000_VALUE;
       }
@@ -1569,12 +1609,12 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     lm = (long) MonthNumber(moString);
     if (ly == 9999 && lm == 12 && ld == 31 && lh == 23 && ln == 59 &&
         ls == 59 && (tmp == 999999999 || tmp == 999 || tmp == 999999)) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return FILLED_TT2000_VALUE;
     } else if (ly == 0 && lm == 1 && ld == 1 && lh == 0 && ln == 0 &&
                ls == 0 && tmp == 0) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return DEFAULT_TT2000_PADVALUE;
     }
@@ -1596,11 +1636,11 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
       }
     }
     if (newstr != NULL) {
-      free (newstr);
+      cdf_FreeMemory (newstr, NULL);
       newstr = NULL;
     }
     if (!YearWithin(ly) && !ValidateYMD(ly,lm,ld)) return ILLEGAL_TT2000_VALUE;
-    free (tmpPtr);
+    cdf_FreeMemory (tmpPtr, NULL);
     tmpPtr = NULL;
     return CDF_TT2000_from_UTC_parts ((double) ly, (double) lm, (double) ld,
                                       (double) lh, (double) ln, (double) ls,
@@ -1609,7 +1649,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     long long tmp;
     if (sscanf(tmpPtr,"%4ld%2ld%2ld.%lld",
         &ly, &lm, &ld, &tmp) != 4) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
@@ -1621,16 +1661,16 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
       fraction = tmp / pow(10.0, len);
     }
     if (ly == 9999 && lm == 12 && ld == 31 && tmp == 9999999999LL) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return FILLED_TT2000_VALUE;
     } else if (ly == 0 && lm == 1 && ld == 1 && tmp == 0) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return DEFAULT_TT2000_PADVALUE;
     }
     if (!YearWithin(ly) && !ValidateYMD(ly,lm,ld)) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
@@ -1645,7 +1685,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     fraction = (fraction - ll) * 1000.0;
     lu = (long) floor(fraction);
     la = (long) ((fraction - lu) * 1000.0);
-    free (tmpPtr);
+    cdf_FreeMemory (tmpPtr, NULL);
     tmpPtr = NULL;
     return CDF_TT2000_from_UTC_parts ((double) ly, (double) lm, (double) ld,
                                       (double) lh, (double) ln, (double) ls,
@@ -1653,33 +1693,33 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
   } else if (style == 2) {
     if (sscanf(tmpPtr,"%4ld%2ld%2ld%2ld%2ld%2ld",
         &ly, &lm, &ld, &lh, &ln, &ls) != 6) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
     if (ly == 9999 && lm == 12 && ld == 31 && lh == 23 && ln == 59 &&
         ls == 59) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return FILLED_TT2000_VALUE;
     } else if (ly == 0 && lm == 1 && ld == 1 && lh == 0 && ln == 0 &&
                ls == 0) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return DEFAULT_TT2000_PADVALUE;
     }
     if (!YearWithin(ly) && !ValidateYMD(ly,lm,ld)) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
-    free (tmpPtr);
+    cdf_FreeMemory (tmpPtr, NULL);
     tmpPtr = NULL;
     return CDF_TT2000_from_UTC_parts ((double) ly, (double) lm, (double) ld,
                                       (double) lh, (double) ln, (double) ls,
                                       0.0, 0.0, 0.0);
   } else if (style == 3 || style == 4) {
-    int len; long tmp; char string2[TT2000_0_STRING_LEN+1];
+    int len; long tmp;
     char ac, tmp2[10], *dot;
     strcpyX (tmp2, "000000000", 9);
     len = (int) strlen (tmpPtr);
@@ -1688,14 +1728,14 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
       if (tmpPtr[len-1] != 'Z') {
         if (sscanf(tmpPtr,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ld",
             &ly, &lm, &ld, &ac, &lh, &ln, &ls) != 7) {
-          free (tmpPtr);
+          cdf_FreeMemory (tmpPtr, NULL);
           tmpPtr = NULL;
           return ILLEGAL_TT2000_VALUE;
         }
       } else {
         if (sscanf(tmpPtr,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ldZ",
             &ly, &lm, &ld, &ac, &lh, &ln, &ls) != 7) {
-          free (tmpPtr);
+          cdf_FreeMemory (tmpPtr, NULL);
           tmpPtr = NULL;
           return ILLEGAL_TT2000_VALUE;
         }
@@ -1703,7 +1743,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     } else {
       if (sscanf(tmpPtr,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ld.",
           &ly, &lm, &ld, &ac, &lh, &ln, &ls) != 7) {
-        free (tmpPtr);
+        cdf_FreeMemory (tmpPtr, NULL);
         tmpPtr = NULL;
         return ILLEGAL_TT2000_VALUE;
       }
@@ -1718,12 +1758,12 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     if (sscanf(tmp2,"%ld", &tmp) != 1) return ILLEGAL_TT2000_VALUE;
     if (ly == 9999 && lm == 12 && ld == 31 && lh == 23 && ln == 59 &&
         ls == 59 && (tmp == 999999999 || tmp == 999 || tmp == 999999)) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return FILLED_TT2000_VALUE;
     } else if (ly == 0 && lm == 1 && ld == 1 && lh == 0 && ln == 0 &&
                ls == 0 && tmp == 0) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return DEFAULT_TT2000_PADVALUE;
     }
@@ -1736,17 +1776,17 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
       la = (long) (tmp - lu * 1000);
     }
     if (!YearWithin(ly) && !ValidateYMD(ly,lm,ld)) {
-      free (tmpPtr);
+      cdf_FreeMemory (tmpPtr, NULL);
       tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
-    free (tmpPtr);
+    cdf_FreeMemory (tmpPtr, NULL);
     tmpPtr = NULL;
     return CDF_TT2000_from_UTC_parts ((double) ly, (double) lm, (double) ld,
                                       (double) lh, (double) ln, (double) ls,
                                       (double) ll, (double) lu, (double) la);
   } else {
-    free (tmpPtr);
+    cdf_FreeMemory (tmpPtr, NULL);
     tmpPtr = NULL;
     return ILLEGAL_TT2000_VALUE;
   }
@@ -1756,7 +1796,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
 * AddOpenCDFCount.
 ******************************************************************************/
 
-VISIBLE_PREFIX void AddOpenCDFsCount ()
+VISIBLE_PREFIX void AddOpenCDFsCount (void)
 {
   ++openCDF64s;
 }
@@ -1765,7 +1805,7 @@ VISIBLE_PREFIX void AddOpenCDFsCount ()
 * ReduceOpenCDFCount.
 ******************************************************************************/
 
-VISIBLE_PREFIX void ReduceOpenCDFsCount ()
+VISIBLE_PREFIX void ReduceOpenCDFsCount (void)
 {
   --openCDF64s;
   CDFClearLeapSecondsTable();
@@ -1786,8 +1826,9 @@ VISIBLE_PREFIX void ReduceOpenCDFsCount ()
 * using the older table, which can be bad after 2017-01-01).
 ******************************************************************************/
 
-VISIBLE_PREFIX int ValidateTT2000 (int yyyymmdd,
-                                   int leapSecondLastUpdated)
+VISIBLE_PREFIX int ValidateTT2000 (
+int yyyymmdd,
+int leapSecondLastUpdated)
 {
   int i, last, lastDate;
   if (yyyymmdd < lastLeapSecondDay) return 1;
@@ -1820,7 +1861,8 @@ VISIBLE_PREFIX int ValidateTT2000 (int yyyymmdd,
 * Otherwise, 0.
 ******************************************************************************/
 
-VISIBLE_PREFIX int ValidateLeapSecondLastUpdated (int leapSecondLastUpdated)
+VISIBLE_PREFIX int ValidateLeapSecondLastUpdated (
+int leapSecondLastUpdated)
 {
   int i, last;
   if (LTD == NULL) LoadLeapSecondsTable ();
@@ -1844,7 +1886,8 @@ VISIBLE_PREFIX int ValidateLeapSecondLastUpdated (int leapSecondLastUpdated)
 * day. 
 ******************************************************************************/
     
-static int LeapSecondLastUpdatedinTable (int leapSecondLastUpdated)
+static int LeapSecondLastUpdatedinTable (
+int leapSecondLastUpdated)
 {       
   int i, last;
   if (LTD == NULL) LoadLeapSecondsTable ();
@@ -1856,9 +1899,17 @@ static int LeapSecondLastUpdatedinTable (int leapSecondLastUpdated)
   return 0;
 }       
 
-static void FromUTCISO8601string (char *string, long *ly, long *lm, long *ld,
-                                  long *lh, long *ln, long *ls,
-                                  long *ll, long *lu, long *la)
+static void FromUTCISO8601string (
+char *string, 
+long *ly, 
+long *lm, 
+long *ld,
+long *lh, 
+long *ln, 
+long *ls,
+long *ll, 
+long *lu, 
+long *la)
 {
   int style;
 
@@ -1906,7 +1957,7 @@ static void FromUTCISO8601string (char *string, long *ly, long *lm, long *ld,
  * Returns the last leap second day added in the static leap second table.
  *****************************************************************************/
 
-int LastLeapSecondDayInStaticTable ()
+int LastLeapSecondDayInStaticTable (void)
 {
   return (int) lastLeapSecondDay;
 }
@@ -1918,10 +1969,10 @@ int LastLeapSecondDayInStaticTable ()
  * 1970-01-01 00:00:00 UTC) in double.
  *****************************************************************************/
 
-VISIBLE_PREFIX void TT2000toUnixTime (epoch, unixTime, numTimes)
-long long *epoch;
-double *unixTime;
-int    numTimes;
+VISIBLE_PREFIX void TT2000toUnixTime (
+long long *epoch,
+double *unixTime,
+int    numTimes)
 { 
   int i; double value, yy, mm, dd, hh, mn, ss, ms, us, ns; 
   for (i = 0; i < numTimes; ++i) {
@@ -1941,10 +1992,10 @@ int    numTimes;
  * 64-bit long.
  *****************************************************************************/
 
-VISIBLE_PREFIX void UnixTimetoTT2000 (unixTime, epoch, numTimes)
-double *unixTime;
-long long *epoch;
-int    numTimes;
+VISIBLE_PREFIX void UnixTimetoTT2000 (
+double *unixTime,
+long long *epoch,
+int    numTimes)
 {
   int i; long long tt2000, tmp2;
   long yy, mm, dd, hh, mn, ss, ms, us;
