@@ -49,10 +49,10 @@ static Logical RegularVar PROTOARGs((
 * EditVars.  This function handles both rVariables and zVariables.
 ******************************************************************************/
 
-Logical EditVars (Z, CDFname, useFormat)
-Logical Z;
-char *CDFname;
-Logical useFormat;
+Logical EditVars (
+Logical Z,
+char *CDFname,
+Logical useFormat)
 {
    CDFstatus status;
    long varN;
@@ -289,7 +289,7 @@ Logical useFormat;
 	       ItemWindow (DELETEiw, &IW);
 	       return FALSE;
 	     }
-	     PW.maxChars = (int) (2 + numDims);
+	     PW.maxChars = (int) (2 + numDims + 1);
 	     EncodeVariances (PW.value, recVary, numDims, dimVarys);
 	     delim = PickDelimiter(varName, strlen(varName));
 	     snprintf (label, (size_t) sizeof(label),
@@ -411,7 +411,7 @@ Logical useFormat;
        ***********************************************************************/
        case DELETEVARkey_EDIT: {
 	 char varName[CDF_VAR_NAME_LEN256+1], delim,
-	      question[21+CDF_VAR_NAME_LEN256+1];
+	      question[76+1];
 	 if (IW.nItems == 0) {
 	   ProblemWindow (BOO(Z,"Nothing selected (no zVariables exist).",
 			        "Nothing selected (no rVariables exist)."),
@@ -428,8 +428,19 @@ Logical useFormat;
 	 }
 	 delim = PickDelimiter (varName, strlen(varName));
 	 snprintf (question, (size_t) sizeof(question),
-		   "Delete %sVariable %c%s%c ?",
-		   BOO(Z,"z","r"), delim, varName, delim);
+		   "Delete %sVariable %c%c ?",
+		   BOO(Z,"z","r"), delim, delim);
+	 used = (int) strlen (question);
+	 numShown = numCharsShown (sizeof(question)-1, used, varName);
+	 if (numShown > 0)
+	   snprintf (question, (size_t) sizeof(question),
+		     "Delete %sVariable %c%.*s%c ?",
+		     BOO(Z,"z","r"), delim, (int)strlen(varName), varName,
+		     delim);
+	 else
+	   snprintf (question, (size_t) sizeof(question),
+		     "Delete %sVariable %c%.*s%s%c ?",
+		     BOO(Z,"z","r"), delim, -numShown, varName, dots3, delim);
 	 if (ConfirmWindow(4,78,question,NULL,FALSE,DELETEVARhelpID)) {
 	   status = CDFlib (DELETE_, BOO(Z,zVAR_,rVAR_),
 			    NULL_);
@@ -471,10 +482,10 @@ Logical useFormat;
 * BuildVarMenu.
 ******************************************************************************/
 
-Logical BuildVarMenu (Z, CDFname, IW)
-Logical Z;
-char *CDFname;
-struct ItemWindowStruct *IW;
+Logical BuildVarMenu (
+Logical Z,
+char *CDFname,
+struct ItemWindowStruct *IW)
 {
    CDFstatus status;
    long nVars, varN, dataType, numElems, maxRec, nRecords;
@@ -519,7 +530,7 @@ struct ItemWindowStruct *IW;
      EncodeDimensionality (&(IW->hLines[0][strlen(IW->hLines[0])]), numDims,
 			   dimSizes,
 			   (size_t) sizeof(BLANKs78)-strlen(IW->hLines[0]));
-     strcatX (IW->hLines[0], " dimensionality, ", 0);
+     strcatX (IW->hLines[0], " dimensionality, ", 17, strlen(IW->hLines[0]), 0);
      snprintf (&(IW->hLines[0][strlen(IW->hLines[0])]), 
 	       (size_t) sizeof(BLANKs78)-strlen(IW->hLines[0]),
 	       "%ld rRecord%s", nRecords, (nRecords <= 1 ? "" : "s"));
@@ -576,9 +587,10 @@ struct ItemWindowStruct *IW;
       snprintf (&field[strlen(field)], (size_t) sizeof(field)-strlen(field),
 	        "%ld", numElems);
       if (strlen(field) > (size_t) DATASPEC_FIELD_LEN) {
-	strcpyX (field + DATASPEC_FIELD_LEN - 3, "...", 0);
+	strcpyX (field + DATASPEC_FIELD_LEN - 3, dots3, 0);
       }
-      strcatX (IW->iLines[(int)varN], field, 0);
+      strcatX (IW->iLines[(int)varN], field, strlen(field),
+	       strlen(IW->iLines[(int)varN]), 0);
       if (strlen(field) < (size_t) DATASPEC_FIELD_LEN) {
 	CatNcharacters (IW->iLines[(int)varN],
 			DATASPEC_FIELD_LEN - strlen(field), (int) ' ');
@@ -602,9 +614,10 @@ struct ItemWindowStruct *IW;
 	}
 	catchrX (field, (int) ']', 0);
 	if (strlen(field) > (size_t) DIMENSIONS_FIELD_LEN) {
-	  strcpyX (field + DIMENSIONS_FIELD_LEN - 3, "...", 0);
+	  strcpyX (field + DIMENSIONS_FIELD_LEN - 3, dots3, 0);
 	}
-	strcatX (IW->iLines[(int)varN], field, 0);
+	strcatX (IW->iLines[(int)varN], field, strlen(field),
+		 strlen(IW->iLines[(int)varN]), 0);
 	if (strlen(field) < (size_t) DIMENSIONS_FIELD_LEN) {
 	  CatNcharacters (IW->iLines[(int)varN],
 			  DIMENSIONS_FIELD_LEN - strlen(field), (int) ' ');
@@ -623,12 +636,14 @@ struct ItemWindowStruct *IW;
       ************************************************************************/
       snprintf (field, (size_t) sizeof(field), "%s/", TFvarianceToken(recVary));
       for (dimN = 0; dimN < numDims; dimN++) {
-	 strcatX (field, TFvarianceToken(dimVarys[dimN]), 0);
+	 strcatX (field, TFvarianceToken(dimVarys[dimN]), 
+		  strlen(TFvarianceToken(dimVarys[dimN])), strlen(field), 0);
       }
       if (strlen(field) > (size_t) VARIANCES_FIELD_LEN) {
-	strcpyX (field + VARIANCES_FIELD_LEN - 3, "...", 0);
+	strcpyX (field + VARIANCES_FIELD_LEN - 3, dots3, 0);
       }
-      strcatX (IW->iLines[(int)varN], field, 0);
+      strcatX (IW->iLines[(int)varN], field, strlen(field),
+	       strlen(IW->iLines[(int)varN]), 0);
       if (strlen(field) < (size_t) VARIANCES_FIELD_LEN) {
 	CatNcharacters (IW->iLines[(int)varN],
 			VARIANCES_FIELD_LEN - strlen(field), (int) ' ');
@@ -650,7 +665,8 @@ struct ItemWindowStruct *IW;
 	curCol += DIMENSIONS_FIELD_LEN + DIMENSIONS_FIELD_BLANKS;
       }
       strcpyX (field, (Z ? "<zEntries>" : "<rEntries>"), 0);
-      strcatX (IW->iLines[(int)varN], field, 0);
+      strcatX (IW->iLines[(int)varN], field, strlen(field),
+	       strlen(IW->iLines[(int)varN]), 0);
       CatNcharacters (IW->iLines[(int)varN], 1, (int) ' ');
       IW->iLineNs[curItem] = (int) varN;
       IW->iCols[curItem] = curCol;
@@ -662,11 +678,12 @@ struct ItemWindowStruct *IW;
       * Setup "values" item.
       ************************************************************************/
       strcpyX (field, "<values>", 0);
-      strcatX (IW->iLines[(int)varN], field, 0);
+      strcatX (IW->iLines[(int)varN], field, strlen(field),
+	       strlen(IW->iLines[(int)varN]), 0);
       CatNcharacters (IW->iLines[(int)varN], 1, (int) ' ');
       IW->iLineNs[curItem] = (int) varN;
       IW->iCols[curItem] = curCol;
-      IW->iLens[curItem] = UTF8StrLength (field, (int)strlen(field));
+      IW->iLens[curItem] = UTF8StrChars (field, (int)strlen(field));
       IW->ibLens[curItem] = (int) strlen (field);
       curCol += strlen(field) + 1;
       curItem++;
@@ -674,7 +691,8 @@ struct ItemWindowStruct *IW;
       * Setup "more" item.
       ************************************************************************/
       strcpyX (field, "<more>", 0);
-      strcatX (IW->iLines[(int)varN], field, 0);
+      strcatX (IW->iLines[(int)varN], field, strlen(field),
+	       strlen(IW->iLines[(int)varN]), 0);
       IW->iLineNs[curItem] = (int) varN;
       IW->iCols[curItem] = curCol;
       IW->iLens[curItem] = (int) strlen(field);
@@ -689,12 +707,12 @@ struct ItemWindowStruct *IW;
 * EditVarValues.
 ******************************************************************************/
 
-Logical EditVarValues (Z, varNum, nVars, useFormat, changed)
-Logical Z;
-long varNum;
-long nVars;
-Logical useFormat;
-Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
+Logical EditVarValues (
+Logical Z,
+long varNum,
+long nVars,
+Logical useFormat,
+Logical *changed)	/* Assumed to be initialized to FALSE by caller. */
 {
   CDFstatus status; size_t nBytes; Logical overflow, done;
   long dataType, numElems, numDims, dimSizes[CDF_MAX_DIMS], recVary;
@@ -920,7 +938,7 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
 	       EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI,
 				     HELPkey_FSI);
 	       snprintf (PW.value, (size_t) sizeof(value),
-			 "%ld", recNum + 1);
+			 "%*ld", numSpaces(recNum+1), recNum + 1);
 	       PromptWindow (NEWpw, &PW, (int) strlen(PW.value), LogicalTRUE);
 	       for (;;) {
 		  if (EnterPW(&PW,RECNUMBERhelpID)) {
@@ -1003,7 +1021,7 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
 	       nBytes = (size_t) (PW.maxChars + 1);
 	       PW.value = (char *) cdf_AllocateMemory (nBytes, FatalError);
 	       strcpyX (PW.value, vString, PW.maxChars);
-	       ix = UTF8StrLength (PW.value, (int)nBytes);
+	       ix = UTF8StrChars (PW.value, (int)nBytes);
 	       PromptWindow (NEWpw, &PW,
 			     (int) BOO(STRINGdataType(dataType),
 				       ix-1, ix), LogicalTRUE);
@@ -1053,9 +1071,11 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
 			strcpyX (tempS, "Illegal number of elements ",
 				 MAX_MESSAGE_TEXT_LEN);
 			if (nElemsEntered > numElems)
-			  strcatX (tempS, "(too many).", MAX_MESSAGE_TEXT_LEN);
+			  strcatX (tempS, "(too many).", 11, strlen(tempS), 
+				   MAX_MESSAGE_TEXT_LEN);
 			else
-			  strcatX (tempS, "(too few).", MAX_MESSAGE_TEXT_LEN);
+			  strcatX (tempS, "(too few).", 10, strlen(tempS),
+				   MAX_MESSAGE_TEXT_LEN);
 			ProblemWindow (tempS, FALSE);
 			cdf_FreeMemory (newBinary, FatalError);
 		      }
@@ -1094,7 +1114,7 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
 	     dimN = IW.itemN - 1;
 	     if (dimVarys[dimN]) {
 	       snprintf (PW.value, (size_t) sizeof(value),
-			 "%ld", indices[dimN]+1);
+			 "%*ld", numSpaces(indices[dimN]+1), indices[dimN]+1);
 	       PromptWindow (NEWpw, &PW, (int) strlen(PW.value), LogicalTRUE);
 	       for (;;) {
 		  if (EnterPW(&PW,DIMINDEXhelpID)) {
@@ -1169,27 +1189,25 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
 * BuildVarValueLine.
 ******************************************************************************/
 
-Logical BuildVarValueLine (Z, recNum, recVary, numDims, indices, dimVarys,
-			   dataType, numElems, binary, vString, vLine, nItems,
-			   vvCols, vvLens, nCols, format, overflow, width)
-Logical Z;
-long recNum;
-long recVary;
-long numDims;
-long *indices;
-long *dimVarys;
-long dataType;
-long numElems;
-void *binary;
-char *vString;
-char *vLine;
-int *nItems;
-int *vvCols;
-int *vvLens;
-int nCols;
-char *format;
-Logical *overflow;
-size_t width;
+Logical BuildVarValueLine (
+Logical Z,
+long recNum,
+long recVary,
+long numDims,
+long *indices,
+long *dimVarys,
+long dataType,
+long numElems,
+void *binary,
+char *vString,
+char *vLine,
+int *nItems,
+int *vvCols,
+int *vvLens,
+int nCols,
+char *format,
+Logical *overflow,
+size_t width)
 {
    CDFstatus status; int dimN; Logical virtual;
    static char virtualT[] = " <virtual>";
@@ -1206,12 +1224,12 @@ size_t width;
      strcpyX (vLine, "*", 0);
    vvLens[itemN] = strlen(vLine);
    itemN++;
-   strcatX (vLine, ":[", 0);
+   strcatX (vLine, ":[", 2, strlen(vLine), 0);
    /***************************************************************************
    * Encode dimension indices.
    ***************************************************************************/
    for (dimN = 0; dimN < numDims; dimN++) {
-      if (dimN != 0) strcatX (vLine, ",", 0);
+      if (dimN != 0) strcatX (vLine, ",", 1, strlen(vLine), 0);
       vvCols[itemN] = strlen(vLine);
       if (dimVarys[dimN])
 	snprintf (EofS(vLine), (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine),
@@ -1221,7 +1239,7 @@ size_t width;
       vvLens[itemN] = strlen (&vLine[vvCols[itemN]]);
       itemN++;
    }
-   strcatX (vLine, "] = ", 0);
+   strcatX (vLine, "] = ", 4, strlen(vLine), 0);
    /***************************************************************************
    * Encode value.
    ***************************************************************************/
@@ -1291,9 +1309,9 @@ size_t width;
      n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
 			       -BOO(virtual,availCols,-1), availCols, style,
 			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
-   if (virtual) strcatX (vLine, virtualT, 0);
-   vvLens[itemN] =  UTF8StrLength (&vLine[vvCols[itemN]],
-                                   (int)strlen(&vLine[vvCols[itemN]]));
+   if (virtual) strcatX (vLine, virtualT, strlen(virtualT), strlen(vLine), 0);
+   vvLens[itemN] =  UTF8StrChars (&vLine[vvCols[itemN]],
+                                  (int)strlen(&vLine[vvCols[itemN]]));
    *nItems = itemN + 1;
    if (FLOAT4dataType(dataType)) {
      if (!isnan((double)*(float *)binary) &&
@@ -1342,13 +1360,13 @@ size_t width;
 * EditVarMore.
 ******************************************************************************/
 
-Logical EditVarMore (Z, varN, useFormat, changed, nVars)
-Logical Z;
-long varN;
-Logical useFormat;
-Logical *changed;        /* Only report changes that affect the caller.
+Logical EditVarMore (
+Logical Z,
+long varN,
+Logical useFormat,
+Logical *changed,        /* Only report changes that affect the caller.
 			   Assumed to be initialized to FALSE by caller. */
-long nVars;
+long nVars)
 {
    CDFstatus status; static Logical first = TRUE;
    AOSs6 (header, BLANKs78, BLANKs78, BLANKs78, BLANKs78, BLANKs78,
@@ -1743,12 +1761,12 @@ long nVars;
 * BuildVarMoreMenu.
 ******************************************************************************/
 
-Logical BuildVarMoreMenu (Z, varN, IW, useFormat, center)
-Logical Z;
-long varN;
-struct ItemWindowStruct *IW;
-Logical useFormat;
-Logical center;		/* Center messages displayed? */
+Logical BuildVarMoreMenu (
+Logical Z,
+long varN,
+struct ItemWindowStruct *IW,
+Logical useFormat,
+Logical center)		/* Center messages displayed? */
 {
   CDFstatus status; char varName[CDF_VAR_NAME_LEN256+1];
   long dataType, numElems, maxRec, maxAllocRec, nAllocRecs, blockingFactor;
@@ -1806,10 +1824,11 @@ Logical center;		/* Center messages displayed? */
 	    numElems);
   pad = VAR_MORE_MENU_1st_HALF_LEN - strlen(IW->hLines[0]);
   if (pad > 0) CatNcharacters (IW->hLines[0], pad, (int) ' ');
-  strcatX (IW->hLines[0], "Dimensionality: ", 0);
+  strcatX (IW->hLines[0], "Dimensionality: ", 16, strlen(IW->hLines[0]), 0);
   EncodeDimensionality (EofS(IW->hLines[0]), numDims, dimSizes,
 		        (size_t) sizeof(BLANKs78)-strlen(IW->hLines[0]));
-  strcatX (IW->hLines[0], BOO(Z," (z)"," (r)"), 0);
+  strcatX (IW->hLines[0], BOO(Z," (z)"," (r)"), BOO(Z,4,4),
+	   strlen(IW->hLines[0]), 0);
   /****************************************************************************
   * Encode 2nd header line.
   ****************************************************************************/
@@ -1817,7 +1836,7 @@ Logical center;		/* Center messages displayed? */
 	    "   Records: %ldn/%ldx", nRecords, maxRec + 1);
   pad = VAR_MORE_MENU_1st_HALF_LEN - strlen(IW->hLines[1]);
   if (pad > 0) CatNcharacters (IW->hLines[1], pad, (int) ' ');
-  strcatX (IW->hLines[1], "     Variances: ", 0);
+  strcatX (IW->hLines[1], "     Variances: ", 16, strlen(IW->hLines[1]), 0);
   EncodeVariances (EofS(IW->hLines[1]), recVary, numDims, dimVarys);
   /****************************************************************************
   * Encode 3rd header line.
@@ -1875,16 +1894,12 @@ Logical center;		/* Center messages displayed? */
 		    strlen(defaultT);
         if (STRINGdataType(dataType)) {
           memset ((char *) padBinary, (int)'\0', (size_t) numElems);
-/*
-          int ix;
-          for (ix = 0; ix < (int) numElems; ++ix)
-             *(((char *) padBinary)+ix) = (char) '\0';
-*/
         }
         EncodeValuesFormat (dataType, numElems, padBinary, EofS(IW->hLines[4]),
 			    format, -1, maxWidth, style,
 		            (size_t) sizeof(BLANKs78)-strlen(IW->hLines[4]));
-        strcatX (IW->hLines[4], defaultT, 0);
+        strcatX (IW->hLines[4], defaultT, strlen(defaultT),
+		 strlen(IW->hLines[4]), 0);
         break;
       }
     default: {
@@ -1898,7 +1913,8 @@ Logical center;		/* Center messages displayed? */
   }
   status = GetFILLVALEntry (id, Z, varN, &dataType2, &numElems2, &fillVal);
   if (status == CDF_OK) 
-    strcatX (IW->hLines[4], " (*Used vAttribute FILLVAL instead)", 0); 
+    strcatX (IW->hLines[4], " (*Used vAttribute FILLVAL instead)", 35,
+	     strlen(IW->hLines[4]), 0); 
   if (padBinary != NULL) cdf_FreeMemory (padBinary, FatalError);
   if (fillVal != NULL) cdf_FreeMemory (fillVal, FatalError);
   if (format != NULL) cdf_FreeMemory (format, FatalError);
@@ -1924,9 +1940,9 @@ Logical center;		/* Center messages displayed? */
 * an illegal name could have been specified).
 ******************************************************************************/
 
-Logical CreateVar (Z, created)
-Logical Z;
-Logical *created;       /* Set to TRUE if a variable is created. */
+Logical CreateVar (
+Logical Z,
+Logical *created)       /* Set to TRUE if a variable is created. */
 {
   CDFstatus status;
   char varName[CDF_VAR_NAME_LEN256+1];
@@ -2045,7 +2061,7 @@ Logical *created;       /* Set to TRUE if a variable is created. */
   /****************************************************************************
   * Prompt for variances.
   ****************************************************************************/
-  PWvary.maxChars = (int) (1 + 1 + numDims);
+  PWvary.maxChars = (int) (1 + 1 + numDims + 1);
   strcpyX (PWvary.value, "", MAX_VARIANCES_LEN);
   PromptWindow (NEWpw, &PWvary, 0, LogicalTRUE);
   for (;;) {
@@ -2085,11 +2101,11 @@ Logical *created;       /* Set to TRUE if a variable is created. */
 * ModPadValue.
 ******************************************************************************/
 
-static Logical ModPadValue (zVar, varN, useFormat, changed)
-Logical zVar;
-long varN;
-Logical useFormat;
-Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
+static Logical ModPadValue (
+Logical zVar,
+long varN,
+Logical useFormat,
+Logical *changed)	/* Assumed to be initialized to FALSE by caller. */
 {
   long dataType, numElems; size_t nBytes; int cursorAt;
   void *binary; char *format; CDFstatus status;
@@ -2240,9 +2256,9 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
 * ModPadValue.
 ******************************************************************************/
 
-static Logical RegularVar (zVar, varN)
-Logical zVar;
-long varN;
+static Logical RegularVar (
+Logical zVar,
+long varN)
 {
   long sr;
   CDFstatus status;
