@@ -42,9 +42,9 @@ MAIN {
 *    Returns FALSE if an error occurred.
 ******************************************************************************/
 
-Logical ValidateCDFs (argC, argV)
-int argC;
-char *argV[];
+Logical ValidateCDFs (
+int argC,
+char *argV[])
 {
   int numParms;
   int count;
@@ -121,22 +121,6 @@ char *argV[];
           DisplayError ("Specify only one debug or quiet qualifier.");
           qopError = TRUE;
       }
-      /************************************************************************
-      * Check for `debug' qualifier.
-      ************************************************************************/
-/*
-      qopError = qopError |! TFqualifier(qop,&debug,DEBUGqual,
-                                         NODEBUGqual,
-                                         DEFAULTdebugValidate, "debug");
-*/
-      /************************************************************************
-      * Check for `quiet' qualifier.
-      ************************************************************************/
-/*
-      qopError = qopError |! TFqualifier(qop,&quiet,QUIETqual,
-                                         NOQUIETqual,
-                                         DEFAULTquietValidate, "quiet");
-*/
       /************************************************************************
       * Get CDF path.
       ************************************************************************/
@@ -186,10 +170,10 @@ char *argV[];
     * Display `validating' message.
     **************************************************************************/
     strcpyX (oText, "Validating \"", 0);
-    strcatX (oText, CDFspec[i], 0);
+    strcatX (oText, CDFspec[i], strlen(CDFspec[i]), strlen(oText), 0);
     if (!EndsWithIgCase(CDFspec[i], ".cdf"))
-      strcatX (oText, ".cdf", 0);
-    strcatX (oText, "\"...", 0);
+      strcatX (oText, ".cdf", 4, strlen(oText), 0);
+    strcatX (oText, "\"...", 4, strlen(oText), 0);
     if (!quiet) OutputWithMargin (stdout, oText, MAX_SCREENLINE_LEN, 0);
     /**************************************************************************
     * Open CDF file, which will validate the file.
