@@ -23,9 +23,9 @@
 ******************************************************************************/
 
 #if defined(mac)
-Logical ExportQOPs (argC, argV)
-int *argC;
-char **argV[];
+Logical ExportQOPs (
+int *argC,
+char **argV[])
 {
   DialogPtr dialogP;
   DialogRecord dRecord;
@@ -246,7 +246,7 @@ char **argV[];
 	*argC = 8 + BOO(NULpString(CDFtext),0,1) +
 		    BOO(NULpString(cacheText),0,2);
 	*argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
-						  FatalError);
+					      FatalError);
 	
 	n = 0;
 	MAKEstrARGv (argV, n, pgmName)
@@ -258,26 +258,59 @@ char **argV[];
 	}
 
 	MAKEstrARGv (argV, n, "-initial");
-	strcpyX (tempS, BOO(outputItems,"output","nooutput"), 0);
-	strcatX (tempS, BOO(useFormat,",format",",noformat"), 0);
-	strcatX (tempS, BOO(showRecord,",record",",norecord"), 0);
-	strcatX (tempS, BOO(showIndices,",indices",",noindices"), 0);
-	strcatX (tempS, BOO(showHeadings,",heading",",noheading"), 0);
-	strcatX (tempS, majoritiesMAC[majority], 0);
-	strcatX (tempS, epochStylesMAC[epochStyle], 0);
-	strcatX (tempS, orientationsMAC[orientation], 0);
+	strcpyX (tempS, BOO(outputItems,"output","nooutput"), 
+		 strlen(BOO(outputItems,"output","nooutput")), strlen(tempS),
+		 0);
+	strcatX (tempS, BOO(useFormat,",format",",noformat"), 
+		 strlen(BOO(useFormat,",format",",noformat")), strlen(tempS),
+		 0);
+	strcatX (tempS, BOO(showRecord,",record",",norecord"),
+		 strlen(BOO(showRecord,",record",",norecord")), strlen(tempS),
+		 0);
+	strcatX (tempS, BOO(showIndices,",indices",",noindices"),
+		 strlen(BOO(showIndices,",indices",",noindices")),
+		 strlen(tempS), 0);
+	strcatX (tempS, BOO(showHeadings,",heading",",noheading"),
+		 strlen(BOO(showHeadings,",heading",",noheading")),
+		 strlen(tempS), 0);
+	strcatX (tempS, majoritiesMAC[majority],
+		 strlen(majoritiesMAC[majority]), strlen(tempS),  0);
+	strcatX (tempS, epochStylesMAC[epochStyle],
+		 strlen(epochStylesMAC[epochStyle]), strlen(tempS),  0);
+	strcatX (tempS, orientationsMAC[orientation],
+		 strlen(orientationsMAC[orientation]), strlen(tempS),  0);
 	if (!simpleMode) {
-	  strcatX (tempS, BOO(useFilters,",filter",",nofilter"), 0);
-	  strcatX (tempS, BOO(useFills,",fills",",nofills"), 0);
-	  strcatX (tempS, BOO(useFillval,",fillval",",nofillval"), 0);
-	  strcatX (tempS, BOO(useValidmin,",validmin",",novalidmin"), 0);
-	  strcatX (tempS, BOO(useValidmax,",validmax",",novalidmax"), 0);
-	  strcatX (tempS, BOO(useMonoton,",monoton",",nomonoton"), 0);
-	  strcatX (tempS, BOO(exclusiveFilters,",exclusive",",noexclusive"),0);
-	  strcatX (tempS, BOO(deleteExisting,",delete",",nodelete"), 0);
-	  strcatX (tempS, BOO(preAllocate,",preallocate",",nopreallocate"), 0);
-	  strcatX (tempS, formatsMAC[newFormat], 0);
-	  strcatX (tempS, encodingsMAC[newEncoding], 0);
+	  strcatX (tempS, BOO(useFilters,",filter",",nofilter"),
+		   strlen(BOO(useFilters,",filter",",nofilter")),
+		   strlen(tempS),  0);
+	  strcatX (tempS, BOO(useFills,",fills",",nofills"), 
+		   strlen(BOO(useFills,",fills",",nofills")),
+		   strlen(tempS), 0);
+	  strcatX (tempS, BOO(useFillval,",fillval",",nofillval"), 
+		   strlen(BOO(useFillval,",fillval",",nofillval")),
+		   strlen(tempS), 0);
+	  strcatX (tempS, BOO(useValidmin,",validmin",",novalidmin"), 
+		   strlen(BOO(useValidmin,",validmin",",novalidmin")),
+		   strlen(tempS), 0);
+	  strcatX (tempS, BOO(useValidmax,",validmax",",novalidmax"), 
+		   strlen(BOO(useValidmax,",validmax",",novalidmax")),
+		   strlen(tempS), 0);
+	  strcatX (tempS, BOO(useMonoton,",monoton",",nomonoton"), 
+		   strlen(BOO(useMonoton,",monoton",",nomonoton")),
+		   strlen(tempS), 0);
+	  strcatX (tempS, BOO(exclusiveFilters,",exclusive",",noexclusive"),
+		   strlen(BOO(exclusiveFilters,",exclusive",",noexclusive")),
+		   strlen(tempS), 0);
+	  strcatX (tempS, BOO(deleteExisting,",delete",",nodelete"), 
+		   strlen(BOO(deleteExisting,",delete",",nodelete")),
+		   strlen(tempS), 0);
+	  strcatX (tempS, BOO(preAllocate,",preallocate",",nopreallocate"), 
+		   strlen(BOO(preAllocate,",preallocate",",nopreallocate")),
+		   strlen(tempS), 0);
+	  strcatX (tempS, formatsMAC[newFormat], 
+		   strlen(formatsMAC[newFormat]), strlen(tempS), 0);
+	  strcatX (tempS, encodingsMAC[newEncoding], 
+		   strlen(encodingsMAC[newEncoding]), strlen(tempS), 0);
 	}
 	MAKEstrARGv (argV, n, tempS);
 
@@ -312,7 +345,8 @@ char **argV[];
       case HELPin: {
 	int n;
 	*argC = 2;
-	*argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *), FatalError);
+	*argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
+					      FatalError);
 	n = 0;
 	MAKEstrARGv (argV, n, pgmName)
 	MAKEstrARGv (argV, n, "-help")
