@@ -93,7 +93,6 @@ long zMode;
 long workingCache, stageCache, compressCache;
 int lineLen, lineIdx, lineIds;
 static char creCDF[] = "creating the CDF";
-static char readG[] = "reading a gAttribute";
 static char creG[] = "creating a gAttribute";
 static char creV[] = "creating a vAttribute";
 static char creZ[] = "creating a zVariable";
@@ -122,6 +121,7 @@ static char padVAR[] = "setting the pad value for the Variable";
 #ifdef WIN32
   static unsigned int oldCodePage = 0;
 #endif
+static Logical longVar;
 
 /******************************************************************************
 * Main.
@@ -147,16 +147,15 @@ MAIN {
 * CreateSkeletonCDF.
 ******************************************************************************/
 
-Logical CreateSkeletonCDF (argC, argV)
-int argC;
-char *argV[];
+Logical CreateSkeletonCDF (
+int argC,
+char *argV[])
 {
   char SKTpath[DU_MAX_PATH_LEN+1];
   char SKTpathX[DU_MAX_PATH_LEN+1];
   char NRVpathX[DU_MAX_PATH_LEN+1];
   Logical comment;
   int i;
-int inGlobal;
   QOP *qop;
   Logical qopError = FALSE;
   static char *validQuals[] = {
@@ -326,23 +325,24 @@ int inGlobal;
       return FALSE;
     }  
   } else {
-    strcatX (SKTpathX, ".skt", DU_MAX_PATH_LEN);
+    strcatX (SKTpathX, ".skt", 4, strlen(SKTpathX), DU_MAX_PATH_LEN);
     SKTfp = fopen (SKTpathX, "r");
     if (SKTfp == NULL) {
       ExpandPath (SKTpath, SKTpathX);
-      strcatX (SKTpathX, ".skeleton_table", DU_MAX_PATH_LEN);
+      strcatX (SKTpathX, ".skeleton_table", 15, strlen(SKTpathX),
+	       DU_MAX_PATH_LEN);
       SKTfp = fopen (SKTpathX, "r");
       if (SKTfp == NULL) {
         ExpandPath (SKTpath, SKTpathX);
-        strcatX (SKTpathX, ".SKT", DU_MAX_PATH_LEN);
+        strcatX (SKTpathX, ".SKT", 4, strlen(SKTpathX), DU_MAX_PATH_LEN);
         SKTfp = fopen (SKTpathX, "r");
         if (SKTfp == NULL) {
           ExpandPath (SKTpath, SKTpathX);
-          strcatX (SKTpathX, ".skt;1", DU_MAX_PATH_LEN);
+          strcatX (SKTpathX, ".skt;1", 6, strlen(SKTpathX), DU_MAX_PATH_LEN);
           SKTfp = fopen (SKTpathX, "r");
 	  if (SKTfp == NULL) {
 	    ExpandPath (SKTpath, SKTpathX);
-	    strcatX (SKTpathX, ".SKT;1", DU_MAX_PATH_LEN);
+	    strcatX (SKTpathX, ".SKT;1", 6, strlen(SKTpathX), DU_MAX_PATH_LEN);
 	    SKTfp = fopen (SKTpathX, "r");
 	    if (SKTfp == NULL) {
 	      ExpandPath (SKTpath, SKTpathX);
@@ -367,23 +367,23 @@ int inGlobal;
   * Open NRV file (may not exist).
   ****************************************************************************/
   ExpandPath (SKTpath, NRVpathX);
-  strcatX (NRVpathX, ".nrv", DU_MAX_PATH_LEN);
+  strcatX (NRVpathX, ".nrv", 4, strlen(NRVpathX), DU_MAX_PATH_LEN);
   NRVfp = fopen (NRVpathX, "r");
   if (NRVfp == NULL) {
     ExpandPath (SKTpath, NRVpathX);
-    strcatX (NRVpathX, ".nrv_file", DU_MAX_PATH_LEN);
+    strcatX (NRVpathX, ".nrv_file", 9, strlen(NRVpathX), DU_MAX_PATH_LEN);
     NRVfp = fopen (NRVpathX, "r");
     if (NRVfp == NULL) {
       ExpandPath (SKTpath, NRVpathX);
-      strcatX (NRVpathX, ".NRV", DU_MAX_PATH_LEN);
+      strcatX (NRVpathX, ".NRV", 4, strlen(NRVpathX), DU_MAX_PATH_LEN);
       NRVfp = fopen (NRVpathX, "r");
       if (NRVfp == NULL) {
-		ExpandPath (SKTpath, NRVpathX);
-		strcatX (NRVpathX, ".nrv;1", DU_MAX_PATH_LEN);
-		NRVfp = fopen (NRVpathX, "r");
+	ExpandPath (SKTpath, NRVpathX);
+	strcatX (NRVpathX, ".nrv;1", 6, strlen(NRVpathX), DU_MAX_PATH_LEN);
+	NRVfp = fopen (NRVpathX, "r");
 	if (NRVfp == NULL) {
 	  ExpandPath (SKTpath, NRVpathX);
-	  strcatX (NRVpathX, ".NRV;1", DU_MAX_PATH_LEN);
+	  strcatX (NRVpathX, ".NRV;1", 6, strlen(NRVpathX), DU_MAX_PATH_LEN);
 	  NRVfp = fopen (NRVpathX, "r");
 	}
       }
@@ -450,7 +450,8 @@ int inGlobal;
 		NextSearchItem (TOKEN, CDFCOMPRESSIONmark);
              } else if (strstrIgCase(line, "cdf_checksum") != NULL) {
 		NextSearchItem (TOKEN, CDFCHECKSUMmark);
-             } else if (strstrIgCase(line, "cdf_leapsecondlastupdated") != NULL) {
+             } else if (strstrIgCase(line, "cdf_leapsecondlastupdated") !=
+			NULL) {
 		NextSearchItem (TOKEN, CDFLEAPSECONDLASTUPDATEDmark);
              } else if (strstrIgCase(line, "var_compression") != NULL) {
 		NextSearchItem (TOKEN, VARCOMPRESSIONmark);
@@ -506,8 +507,8 @@ int inGlobal;
 * end of the skeleton table has been reached).
 ******************************************************************************/
 
-Logical CharStream (chr)
-int chr;
+Logical CharStream (
+int chr)
 {
   CATchr (&stream, chr, &streamZ, BASE_STREAM_SIZE);
   switch (searchFor) {
@@ -520,8 +521,12 @@ int chr;
 	if (token[0] != NUL)
 	  if (!ItemStream(token)) return FALSE;
       }
-      else
-	CATchr (&token, chr, &tokenZ, BASE_TOKEN_SIZE);
+      else {
+        /* For a long variable name that spans more than one line, skip that
+           '-' character in its first line... */
+        if (!longVar || chr != (int) '-')
+	  CATchr (&token, chr, &tokenZ, BASE_TOKEN_SIZE);
+      }
       break;
     /**************************************************************************
     *
@@ -631,7 +636,7 @@ int chr;
 		break;
 	    }
       else
-	if (startBraceFound)
+	if (startBraceFound) {
 	  if (inString) {
 	    if (lineN != stringLineN) {
 	      ParseError ("String/substring split across lines.");
@@ -639,6 +644,7 @@ int chr;
 	    }
 	    CATchr (&eValue, chr, &eValueZ, BASE_EVALUE_SIZE);
 	  }
+	}
       break;
     /**************************************************************************
     *
@@ -771,8 +777,8 @@ int chr;
 * or the end of the skeleton table has been reached).
 ******************************************************************************/
 
-Logical ItemStream (item)
-char *item;
+Logical ItemStream (
+char *item)
 {
   CDFstatus status; Logical zVar = TRUE;
   static long format, majority, encoding, zNumDims, rNumDims, entryNum,
@@ -783,11 +789,12 @@ char *item;
   static long VARYdimVarys[CDF_MAX_DIMS] = {
     VARY, VARY, VARY, VARY, VARY, VARY, VARY, VARY, VARY, VARY
   };
-  long attrNum, numDims = 0, varNum, dimSizes[CDF_MAX_DIMS];
+  long numDims = 0, varNum, dimSizes[CDF_MAX_DIMS];
   long *dimVarysP = NULL;  /* Points to the `dimVarys' array to be used. */
   int dN, dNt;		/* Dimension number. */
   void *padValue;
   size_t nBytes;
+
   /****************************************************************************
   * Based on what should be next...
   ****************************************************************************/
@@ -1219,7 +1226,8 @@ char *item;
         if (!strcmp(item,"CDF_LEAPSECONDLASTUPDATED"))
           NextSearchItem (TOKEN, CDFLEAPSECONDLASTUPDATEDCOLONmark);
         else {
-          ItemError2 ("CDF_LEAPSECONDLASTUPDATED:", "CDF_LEAPSECONDLASTUPDATED", item);
+          ItemError2 ("CDF_LEAPSECONDLASTUPDATED:", "CDF_LEAPSECONDLASTUPDATED",
+		      item);
           return FALSE;
         }
       break;
@@ -1429,8 +1437,8 @@ char *item;
       long vAttrNum;
       strcpyX (vAttrName, item, CDF_ATTR_NAME_LEN256);
       if (!ISTPname (vAttrName) && warning)
-        WriteOutFP (stdout, "Warning: Attribute name: \"%s\" not ISTP compliant... not recommended\n",
-                    vAttrName);
+        WriteOutFP (stdout, "Warning: Attribute name: \"%s\" not ISTP "
+                            "compliant...\n", vAttrName);
       status = CDFlib (CREATE_, ATTR_, vAttrName, VARIABLE_SCOPE, &vAttrNum,
 		       NULL_);
       if (!StatusHandlerS2C(status,creV)) return FALSE;
@@ -1476,10 +1484,50 @@ char *item;
     /**************************************************************************
     *
     **************************************************************************/
-    case VARNAMEfield:
-      strcpyX (varName, item, CDF_VAR_NAME_LEN256);
+    case VARNAMEfield: {
+      char *ptrs, *ptre, *tmpx;
+      ptre = strrchr (line, '"');
+      if (ptre && !strncmp(ptre, "\" -", 3)) {
+        strcpyX (varName, item, 0);
+        if (fgets(line,MAX_SKTLINE_LEN,SKTfp) == NULL) {
+          ParseError ("Unexpected end-of-file.");
+          FreeGrowingStrings ();
+          return done;
+        }
+        ptrs = strchr (line, '"');
+        ptre = strrchr (ptrs+1, '"');
+        while (ptre && !strncmp(ptre, "\" -", 3)) {
+          tmpx = (char *) malloc(ptre-ptrs);
+          strncpy (tmpx, ptrs+1, ptre-ptrs-1);
+          *(tmpx+(ptre-ptrs-1)) = (char ) '\0';
+          strcatX (varName, tmpx, strlen(tmpx), strlen(varName),
+		   CDF_VAR_NAME_LEN256);
+          free (tmpx);
+          tmpx = NULL;
+          if (fgets(line,MAX_SKTLINE_LEN,SKTfp) == NULL) {
+            ParseError ("Unexpected end-of-file.");
+            FreeGrowingStrings ();
+            return done;
+          }
+          ptre = strrchr (line, '"');
+        }
+        ptrs = strchr (line, '"');
+        ptre = strrchr (ptrs+1, '"');
+        tmpx = (char *) malloc(ptre-ptrs);
+        strncpy (tmpx, ptrs+1, ptre-ptrs-1);
+        *(tmpx+(ptre-ptrs-1)) = (char ) '\0'; 
+        strcatX (varName, tmpx, strlen(tmpx), strlen(varName),
+		 CDF_VAR_NAME_LEN256);
+        free (tmpx);
+        tmpx = NULL;
+        longVar = TRUE;
+      } else {
+        strcpyX (varName, item, CDF_VAR_NAME_LEN256);
+        longVar = FALSE;
+      }
       NextSearchItem (TOKEN, VARDATATYPEfield);
       break;
+    }
     /**************************************************************************
     *
     **************************************************************************/
@@ -1574,7 +1622,7 @@ char *item;
 	  zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
           if (!ISTPname (varName) && warning)
             WriteOutFP (stdout,
-		 "Warning: Variable name: \"%s\" non-ISTP compliant... not recommended\n",
+		 "Warning: Variable name: \"%s\" non-ISTP compliant...\n",
                         varName);
 	  if (zVar)
 	    status = CDFlib (CREATE_, zVAR_, varName, vDataType, vNumElems,
@@ -1587,10 +1635,12 @@ char *item;
 
 	  if (!StatusHandlerS2C(status,BOO(zVar,creZ,creR))) return FALSE;
           if (mLog) {
-            char tempS[256+1];
-            snprintf (tempS, 256, "*** created var=%s\n",varName);
+            char tempS[273+1];
+            snprintf (tempS, 274, "*** created var=%s\n",varName);
             WriteOut (stdout, tempS);
           }
+	  /* Reset the longVar once the variable is written. */
+	  if (longVar) longVar = FALSE;
 	  /********************************************************************
 	  * Check if a pad value may possibly be written with the value of the
 	  * FILLVAL (or _Fillval) attribute.  If so, we want to allocate space
@@ -1684,8 +1734,8 @@ char *item;
 
 	  if (!StatusHandlerS2C(status,BOO(zVar,creZ,creR))) return FALSE;
           if (mLog) {
-            char tempS[256+1];
-            snprintf (tempS, 256, "*** created var=%s\n",varName);
+            char tempS[273+1];
+            snprintf (tempS, 274, "*** created var=%s\n",varName);
             WriteOut (stdout, tempS);
           }
 	  /********************************************************************
@@ -2233,9 +2283,9 @@ char *item;
 * NextSearchItem.
 ******************************************************************************/
 
-void NextSearchItem (type, item)
-enum searchForENUM type;
-enum nextItemENUM item;
+void NextSearchItem (
+enum searchForENUM type,
+enum nextItemENUM item)
 {
   searchFor = type;
   switch (type) {
@@ -2288,9 +2338,9 @@ enum nextItemENUM item;
 * ItemError1.  (A specific item was expected).
 ******************************************************************************/
 
-void ItemError1 (expected, found)
-char *expected;
-char *found;
+void ItemError1 (
+char *expected,
+char *found)
 {
   char msg[MAX_MSG_LEN+1];
   snprintf (msg, (size_t) sizeof(msg),
@@ -2303,10 +2353,10 @@ char *found;
 * ItemError2.  (One of two items were expected).
 ******************************************************************************/
 
-void ItemError2 (expected1, expected2, found)
-char *expected1;
-char *expected2;
-char *found;
+void ItemError2 (
+char *expected1,
+char *expected2,
+char *found)
 {
   char msg[MAX_MSG_LEN+1];
   snprintf (msg, (size_t) sizeof(msg),
@@ -2320,11 +2370,11 @@ char *found;
 * ItemError3.  (One of three items were expected).
 ******************************************************************************/
 
-void ItemError3 (expected1, expected2, expected3, found)
-char *expected1;
-char *expected2;
-char *expected3;
-char *found;
+void ItemError3 (
+char *expected1,
+char *expected2,
+char *expected3,
+char *found)
 {
   char msg[MAX_MSG_LEN+1];
   snprintf (msg, (size_t) sizeof(msg),
@@ -2338,8 +2388,8 @@ char *found;
 * ParseError.
 ******************************************************************************/
 
-void ParseError (msg)
-char *msg;
+void ParseError (
+char *msg)
 {
   char tempS[MAX_MSG_LEN+1];
   WriteOut (stdout, msg);
@@ -2361,11 +2411,11 @@ char *msg;
 * maximum length, reallocate the string with a larger size.
 ******************************************************************************/
 
-void CATchr (str, chr, size, base)
-char **str;
-int chr;
-size_t *size;
-int base;
+void CATchr (
+char **str,
+int chr,
+size_t *size,
+int base)
 {
   size_t nChars = (size_t) (*size + base);
   if (strlen(*str) == *size) {
@@ -2381,10 +2431,10 @@ int base;
 * RecurCharStream.
 ******************************************************************************/
 
-Logical RecurCharStream (stream, type, next)
-char *stream;
-enum searchForENUM type;
-enum nextItemENUM next;
+Logical RecurCharStream (
+char *stream,
+enum searchForENUM type,
+enum nextItemENUM next)
 {
   char *streamT; int i;
   size_t nChars = strlen (stream);
@@ -2405,7 +2455,8 @@ enum nextItemENUM next;
 * AllocateGrowingStrings.
 ******************************************************************************/
 
-void AllocateGrowingStrings () {
+void AllocateGrowingStrings (void) 
+{
   streamZ = BASE_STREAM_SIZE;
   stream = (char *) cdf_AllocateMemory ((size_t) (streamZ + 1), FatalError);
   stringZ = BASE_STRING_SIZE;
@@ -2423,7 +2474,8 @@ void AllocateGrowingStrings () {
 * FreeGrowingStrings.
 ******************************************************************************/
 
-void FreeGrowingStrings () {
+void FreeGrowingStrings (void) 
+{
   cdf_FreeMemory (stream, FatalError);
   cdf_FreeMemory (string, FatalError);
   cdf_FreeMemory (token, FatalError);
@@ -2437,7 +2489,8 @@ void FreeGrowingStrings () {
 * Returns TRUE if the CDF was successfully closed.
 ******************************************************************************/
 
-static Logical CloseTheCDF () {
+static Logical CloseTheCDF (void) 
+{
   CDFstatus status;
   if (displayStats) {
     vSTATS vStatsDotCDF, vStatsStage, vStatsCompress;
@@ -2460,9 +2513,9 @@ static Logical CloseTheCDF () {
 * StatusHandlerS2C.
 ******************************************************************************/
 
-Logical StatusHandlerS2C (status, msg)
-CDFstatus status;
-char *msg;
+Logical StatusHandlerS2C (
+CDFstatus status,
+char *msg)
 {
   char text[CDF_STATUSTEXT_LEN+1];
   static char infoT[] = {
@@ -2474,7 +2527,7 @@ char *msg;
   static char errorT[] = {
     "The following ERROR condition was encountered while"
   };
-  char tempS[2*(99+1)+1];
+  char tempS[3*(99+1)+1];
   if (StatusINFO(status) && report[INFOs]) {
     CDFlib (SELECT_, CDF_STATUS_, status,
 	    GET_, STATUS_TEXT_, text,
@@ -2517,9 +2570,9 @@ char *msg;
 ******************************************************************************/
 
 #if defined(mac)
-Logical CreateSkeletonQOPs (argC, argV)
-int *argC;
-char **argV[];
+Logical CreateSkeletonQOPs (
+int *argC,
+char **argV[])
 {
   DialogPtr dialogP;
   DialogRecord dRecord;
